/* File: _stripackmodule.c
 * This file is auto-generated with f2py (version:2).
 * f2py is a Fortran to Python Interface Generator (FPIG), Second Edition,
 * written by Pearu Peterson <pearu@cens.ioc.ee>.
 * Generation date: Wed May 15 20:50:31 2019
 * Do not edit this file directly unless you know what you are doing!!!
 */

#ifdef __cplusplus
extern "C" {
#endif

/*********************** See f2py2e/cfuncs.py: includes ***********************/
#include "Python.h"
#include <stdarg.h>
#include "fortranobject.h"
#include <math.h>

/**************** See f2py2e/rules.py: mod_rules['modulebody'] ****************/
static PyObject *_stripack_error;
static PyObject *_stripack_module;

/*********************** See f2py2e/cfuncs.py: typedefs ***********************/
/*need_typedefs*/

/****************** See f2py2e/cfuncs.py: typedefs_generated ******************/
/*need_typedefs_generated*/

/********************** See f2py2e/cfuncs.py: cppmacros **********************/
#if defined(PREPEND_FORTRAN)
#if defined(NO_APPEND_FORTRAN)
#if defined(UPPERCASE_FORTRAN)
#define F_FUNC(f,F) _##F
#else
#define F_FUNC(f,F) _##f
#endif
#else
#if defined(UPPERCASE_FORTRAN)
#define F_FUNC(f,F) _##F##_
#else
#define F_FUNC(f,F) _##f##_
#endif
#endif
#else
#if defined(NO_APPEND_FORTRAN)
#if defined(UPPERCASE_FORTRAN)
#define F_FUNC(f,F) F
#else
#define F_FUNC(f,F) f
#endif
#else
#if defined(UPPERCASE_FORTRAN)
#define F_FUNC(f,F) F##_
#else
#define F_FUNC(f,F) f##_
#endif
#endif
#endif
#if defined(UNDERSCORE_G77)
#define F_FUNC_US(f,F) F_FUNC(f##_,F##_)
#else
#define F_FUNC_US(f,F) F_FUNC(f,F)
#endif

#define rank(var) var ## _Rank
#define shape(var,dim) var ## _Dims[dim]
#define old_rank(var) (PyArray_NDIM((PyArrayObject *)(capi_ ## var ## _tmp)))
#define old_shape(var,dim) PyArray_DIM(((PyArrayObject *)(capi_ ## var ## _tmp)),dim)
#define fshape(var,dim) shape(var,rank(var)-dim-1)
#define len(var) shape(var,0)
#define flen(var) fshape(var,0)
#define old_size(var) PyArray_SIZE((PyArrayObject *)(capi_ ## var ## _tmp))
/* #define index(i) capi_i ## i */
#define slen(var) capi_ ## var ## _len
#define size(var, ...) f2py_size((PyArrayObject *)(capi_ ## var ## _tmp), ## __VA_ARGS__, -1)

#ifdef DEBUGCFUNCS
#define CFUNCSMESS(mess) fprintf(stderr,"debug-capi:"mess);
#define CFUNCSMESSPY(mess,obj) CFUNCSMESS(mess) \
    PyObject_Print((PyObject *)obj,stderr,Py_PRINT_RAW);\
    fprintf(stderr,"\n");
#else
#define CFUNCSMESS(mess)
#define CFUNCSMESSPY(mess,obj)
#endif

#ifndef max
#define max(a,b) ((a > b) ? (a) : (b))
#endif
#ifndef min
#define min(a,b) ((a < b) ? (a) : (b))
#endif
#ifndef MAX
#define MAX(a,b) ((a > b) ? (a) : (b))
#endif
#ifndef MIN
#define MIN(a,b) ((a < b) ? (a) : (b))
#endif

#if defined(PREPEND_FORTRAN)
#if defined(NO_APPEND_FORTRAN)
#if defined(UPPERCASE_FORTRAN)
#define F_WRAPPEDFUNC(f,F) _F2PYWRAP##F
#else
#define F_WRAPPEDFUNC(f,F) _f2pywrap##f
#endif
#else
#if defined(UPPERCASE_FORTRAN)
#define F_WRAPPEDFUNC(f,F) _F2PYWRAP##F##_
#else
#define F_WRAPPEDFUNC(f,F) _f2pywrap##f##_
#endif
#endif
#else
#if defined(NO_APPEND_FORTRAN)
#if defined(UPPERCASE_FORTRAN)
#define F_WRAPPEDFUNC(f,F) F2PYWRAP##F
#else
#define F_WRAPPEDFUNC(f,F) f2pywrap##f
#endif
#else
#if defined(UPPERCASE_FORTRAN)
#define F_WRAPPEDFUNC(f,F) F2PYWRAP##F##_
#else
#define F_WRAPPEDFUNC(f,F) f2pywrap##f##_
#endif
#endif
#endif
#if defined(UNDERSCORE_G77)
#define F_WRAPPEDFUNC_US(f,F) F_WRAPPEDFUNC(f##_,F##_)
#else
#define F_WRAPPEDFUNC_US(f,F) F_WRAPPEDFUNC(f,F)
#endif

#define CHECKSCALAR(check,tcheck,name,show,var)\
    if (!(check)) {\
        char errstring[256];\
        sprintf(errstring, "%s: "show, "("tcheck") failed for "name, var);\
        PyErr_SetString(_stripack_error,errstring);\
        /*goto capi_fail;*/\
    } else 

/************************ See f2py2e/cfuncs.py: cfuncs ************************/
static int f2py_size(PyArrayObject* var, ...)
{
  npy_int sz = 0;
  npy_int dim;
  npy_int rank;
  va_list argp;
  va_start(argp, var);
  dim = va_arg(argp, npy_int);
  if (dim==-1)
    {
      sz = PyArray_SIZE(var);
    }
  else
    {
      rank = PyArray_NDIM(var);
      if (dim>=1 && dim<=rank)
        sz = PyArray_DIM(var, dim-1);
      else
        fprintf(stderr, "f2py_size: 2nd argument value=%d fails to satisfy 1<=value<=%d. Result will be 0.\n", dim, rank);
    }
  va_end(argp);
  return sz;
}

static int int_from_pyobj(int* v,PyObject *obj,const char *errmess) {
    PyObject* tmp = NULL;
    if (PyInt_Check(obj)) {
        *v = (int)PyInt_AS_LONG(obj);
        return 1;
    }
    tmp = PyNumber_Int(obj);
    if (tmp) {
        *v = PyInt_AS_LONG(tmp);
        Py_DECREF(tmp);
        return 1;
    }
    if (PyComplex_Check(obj))
        tmp = PyObject_GetAttrString(obj,"real");
    else if (PyString_Check(obj) || PyUnicode_Check(obj))
        /*pass*/;
    else if (PySequence_Check(obj))
        tmp = PySequence_GetItem(obj,0);
    if (tmp) {
        PyErr_Clear();
        if (int_from_pyobj(v,tmp,errmess)) {Py_DECREF(tmp); return 1;}
        Py_DECREF(tmp);
    }
    {
        PyObject* err = PyErr_Occurred();
        if (err==NULL) err = _stripack_error;
        PyErr_SetString(err,errmess);
    }
    return 0;
}

static int double_from_pyobj(double* v,PyObject *obj,const char *errmess) {
    PyObject* tmp = NULL;
    if (PyFloat_Check(obj)) {
#ifdef __sgi
        *v = PyFloat_AsDouble(obj);
#else
        *v = PyFloat_AS_DOUBLE(obj);
#endif
        return 1;
    }
    tmp = PyNumber_Float(obj);
    if (tmp) {
#ifdef __sgi
        *v = PyFloat_AsDouble(tmp);
#else
        *v = PyFloat_AS_DOUBLE(tmp);
#endif
        Py_DECREF(tmp);
        return 1;
    }
    if (PyComplex_Check(obj))
        tmp = PyObject_GetAttrString(obj,"real");
    else if (PyString_Check(obj) || PyUnicode_Check(obj))
        /*pass*/;
    else if (PySequence_Check(obj))
        tmp = PySequence_GetItem(obj,0);
    if (tmp) {
        PyErr_Clear();
        if (double_from_pyobj(v,tmp,errmess)) {Py_DECREF(tmp); return 1;}
        Py_DECREF(tmp);
    }
    {
        PyObject* err = PyErr_Occurred();
        if (err==NULL) err = _stripack_error;
        PyErr_SetString(err,errmess);
    }
    return 0;
}


/********************* See f2py2e/cfuncs.py: userincludes *********************/
/*need_userincludes*/

/********************* See f2py2e/capi_rules.py: usercode *********************/


/* See f2py2e/rules.py */
extern void F_FUNC(addnod,ADDNOD)(int*,int*,double*,double*,double*,int*,int*,int*,int*,int*);
extern void F_WRAPPEDFUNC_US(arc_cosine,ARC_COSINE)(double*,double*);
extern void F_WRAPPEDFUNC(areas,AREAS)(double*,double*,double*,double*);
extern void F_FUNC(triareas,TRIAREAS)(int*,double*,double*,double*,int*,int*,double*);
extern void F_FUNC(bnodes,BNODES)(int*,int*,int*,int*,int*,int*,int*,int*);
extern void F_FUNC(circum,CIRCUM)(double*,double*,double*,double*,int*);
extern void F_FUNC(crlist,CRLIST)(int*,int*,double*,double*,double*,int*,int*,int*,int*,int*,int*,int*,double*,double*,double*,double*,int*);
extern void F_FUNC(delarc,DELARC)(int*,int*,int*,int*,int*,int*,int*,int*);
extern void F_FUNC(delnod,DELNOD)(int*,int*,double*,double*,double*,int*,int*,int*,int*,int*,int*,int*);
extern void F_FUNC(edge,EDGE)(int*,int*,double*,double*,double*,int*,int*,int*,int*,int*,int*);
extern void F_WRAPPEDFUNC(nearnd,NEARND)(int*,double*,int*,int*,double*,double*,double*,int*,int*,int*,double*);
extern void F_FUNC(trans,TRANS)(int*,double*,double*,double*,double*,double*);
extern void F_FUNC(trfind,TRFIND)(int*,double*,int*,double*,double*,double*,int*,int*,int*,double*,double*,double*,int*,int*,int*);
extern void F_FUNC(trmesh,TRMESH)(int*,double*,double*,double*,int*,int*,int*,int*);
extern void F_FUNC(interp,INTERP)(int*,int*,double*,double*,double*,double*,double*,double*,int*,int*,int*,int*,double*,int*);
extern void F_FUNC(getnp,GETNP)(double*,double*,double*,int*,int*,int*,int*,int*,double*,int*);
extern void F_FUNC_US(interp_n,INTERP_N)(int*,int*,int*,double*,double*,double*,double*,double*,double*,int*,int*,int*,double*,int*,int*);
extern void F_FUNC(trlist,TRLIST)(int*,int*,int*,int*,int*,int*,int*,int*);
extern void F_FUNC(trlist2,TRLIST2)(int*,int*,int*,int*,int*,int*,int*);
/*eof externroutines*/

/******************** See f2py2e/capi_rules.py: usercode1 ********************/


/******************* See f2py2e/cb_rules.py: buildcallback *******************/
/*need_callbacks*/

/*********************** See f2py2e/rules.py: buildapi ***********************/

/*********************************** addnod ***********************************/
static char doc_f2py_rout__stripack_addnod[] = "\
list,lptr,lend,lnew,ier = addnod(x,y,z,list,lptr,lend,lnew,[nst])\n\nWrapper for ``addnod``.\
\n\nParameters\n----------\n"
"x : input rank-1 array('d') with bounds (k)\n"
"y : input rank-1 array('d') with bounds (k)\n"
"z : input rank-1 array('d') with bounds (k)\n"
"list : input rank-1 array('i') with bounds (6 * k - 12)\n"
"lptr : input rank-1 array('i') with bounds (6 * k - 12)\n"
"lend : input rank-1 array('i') with bounds (k)\n"
"lnew : input int\n"
"\nOther Parameters\n----------------\n"
"nst : input int, optional\n    Default: 1\n"
"\nReturns\n-------\n"
"list : rank-1 array('i') with bounds (6 * k - 12)\n"
"lptr : rank-1 array('i') with bounds (6 * k - 12)\n"
"lend : rank-1 array('i') with bounds (k)\n"
"lnew : int\n"
"ier : int";
/* extern void F_FUNC(addnod,ADDNOD)(int*,int*,double*,double*,double*,int*,int*,int*,int*,int*); */
static PyObject *f2py_rout__stripack_addnod(const PyObject *capi_self,
                           PyObject *capi_args,
                           PyObject *capi_keywds,
                           void (*f2py_func)(int*,int*,double*,double*,double*,int*,int*,int*,int*,int*)) {
  PyObject * volatile capi_buildvalue = NULL;
  volatile int f2py_success = 1;
/*decl*/

  int nst = 0;
  PyObject *nst_capi = Py_None;
  int k = 0;
  double *x = NULL;
  npy_intp x_Dims[1] = {-1};
  const int x_Rank = 1;
  PyArrayObject *capi_x_tmp = NULL;
  int capi_x_intent = 0;
  PyObject *x_capi = Py_None;
  double *y = NULL;
  npy_intp y_Dims[1] = {-1};
  const int y_Rank = 1;
  PyArrayObject *capi_y_tmp = NULL;
  int capi_y_intent = 0;
  PyObject *y_capi = Py_None;
  double *z = NULL;
  npy_intp z_Dims[1] = {-1};
  const int z_Rank = 1;
  PyArrayObject *capi_z_tmp = NULL;
  int capi_z_intent = 0;
  PyObject *z_capi = Py_None;
  int *list = NULL;
  npy_intp list_Dims[1] = {-1};
  const int list_Rank = 1;
  PyArrayObject *capi_list_tmp = NULL;
  int capi_list_intent = 0;
  PyObject *list_capi = Py_None;
  int *lptr = NULL;
  npy_intp lptr_Dims[1] = {-1};
  const int lptr_Rank = 1;
  PyArrayObject *capi_lptr_tmp = NULL;
  int capi_lptr_intent = 0;
  PyObject *lptr_capi = Py_None;
  int *lend = NULL;
  npy_intp lend_Dims[1] = {-1};
  const int lend_Rank = 1;
  PyArrayObject *capi_lend_tmp = NULL;
  int capi_lend_intent = 0;
  PyObject *lend_capi = Py_None;
  int lnew = 0;
  PyObject *lnew_capi = Py_None;
  int ier = 0;
  static char *capi_kwlist[] = {"x","y","z","list","lptr","lend","lnew","nst",NULL};

/*routdebugenter*/
#ifdef F2PY_REPORT_ATEXIT
f2py_start_clock();
#endif
  if (!PyArg_ParseTupleAndKeywords(capi_args,capi_keywds,\
    "OOOOOOO|O:_stripack.addnod",\
    capi_kwlist,&x_capi,&y_capi,&z_capi,&list_capi,&lptr_capi,&lend_capi,&lnew_capi,&nst_capi))
    return NULL;
/*frompyobj*/
  /* Processing variable nst */
  if (nst_capi == Py_None) nst = 1; else
    f2py_success = int_from_pyobj(&nst,nst_capi,"_stripack.addnod() 1st keyword (nst) can't be converted to int");
  if (f2py_success) {
  /* Processing variable x */
  ;
  capi_x_intent |= F2PY_INTENT_IN;
  capi_x_tmp = array_from_pyobj(NPY_DOUBLE,x_Dims,x_Rank,capi_x_intent,x_capi);
  if (capi_x_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 1st argument `x' of _stripack.addnod to C/Fortran array" );
  } else {
    x = (double *)(PyArray_DATA(capi_x_tmp));

  /* Processing variable lnew */
    f2py_success = int_from_pyobj(&lnew,lnew_capi,"_stripack.addnod() 7th argument (lnew) can't be converted to int");
  if (f2py_success) {
  /* Processing variable ier */
  /* Processing variable k */
  k = len(x);
  /* Processing variable y */
  y_Dims[0]=k;
  capi_y_intent |= F2PY_INTENT_IN;
  capi_y_tmp = array_from_pyobj(NPY_DOUBLE,y_Dims,y_Rank,capi_y_intent,y_capi);
  if (capi_y_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 2nd argument `y' of _stripack.addnod to C/Fortran array" );
  } else {
    y = (double *)(PyArray_DATA(capi_y_tmp));

  /* Processing variable z */
  z_Dims[0]=k;
  capi_z_intent |= F2PY_INTENT_IN;
  capi_z_tmp = array_from_pyobj(NPY_DOUBLE,z_Dims,z_Rank,capi_z_intent,z_capi);
  if (capi_z_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 3rd argument `z' of _stripack.addnod to C/Fortran array" );
  } else {
    z = (double *)(PyArray_DATA(capi_z_tmp));

  /* Processing variable list */
  list_Dims[0]=6 * k - 12;
  capi_list_intent |= F2PY_INTENT_IN|F2PY_INTENT_OUT;
  capi_list_tmp = array_from_pyobj(NPY_INT,list_Dims,list_Rank,capi_list_intent,list_capi);
  if (capi_list_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 4th argument `list' of _stripack.addnod to C/Fortran array" );
  } else {
    list = (int *)(PyArray_DATA(capi_list_tmp));

  /* Processing variable lptr */
  lptr_Dims[0]=6 * k - 12;
  capi_lptr_intent |= F2PY_INTENT_IN|F2PY_INTENT_OUT;
  capi_lptr_tmp = array_from_pyobj(NPY_INT,lptr_Dims,lptr_Rank,capi_lptr_intent,lptr_capi);
  if (capi_lptr_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 5th argument `lptr' of _stripack.addnod to C/Fortran array" );
  } else {
    lptr = (int *)(PyArray_DATA(capi_lptr_tmp));

  /* Processing variable lend */
  lend_Dims[0]=k;
  capi_lend_intent |= F2PY_INTENT_IN|F2PY_INTENT_OUT;
  capi_lend_tmp = array_from_pyobj(NPY_INT,lend_Dims,lend_Rank,capi_lend_intent,lend_capi);
  if (capi_lend_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 6th argument `lend' of _stripack.addnod to C/Fortran array" );
  } else {
    lend = (int *)(PyArray_DATA(capi_lend_tmp));

/*end of frompyobj*/
#ifdef F2PY_REPORT_ATEXIT
f2py_start_call_clock();
#endif
/*callfortranroutine*/
        (*f2py_func)(&nst,&k,x,y,z,list,lptr,lend,&lnew,&ier);
if (PyErr_Occurred())
  f2py_success = 0;
#ifdef F2PY_REPORT_ATEXIT
f2py_stop_call_clock();
#endif
/*end of callfortranroutine*/
    if (f2py_success) {
/*pyobjfrom*/
/*end of pyobjfrom*/
    CFUNCSMESS("Building return value.\n");
    capi_buildvalue = Py_BuildValue("NNNii",capi_list_tmp,capi_lptr_tmp,capi_lend_tmp,lnew,ier);
/*closepyobjfrom*/
/*end of closepyobjfrom*/
    } /*if (f2py_success) after callfortranroutine*/
/*cleanupfrompyobj*/
  }  /*if (capi_lend_tmp == NULL) ... else of lend*/
  /* End of cleaning variable lend */
  }  /*if (capi_lptr_tmp == NULL) ... else of lptr*/
  /* End of cleaning variable lptr */
  }  /*if (capi_list_tmp == NULL) ... else of list*/
  /* End of cleaning variable list */
  if((PyObject *)capi_z_tmp!=z_capi) {
    Py_XDECREF(capi_z_tmp); }
  }  /*if (capi_z_tmp == NULL) ... else of z*/
  /* End of cleaning variable z */
  if((PyObject *)capi_y_tmp!=y_capi) {
    Py_XDECREF(capi_y_tmp); }
  }  /*if (capi_y_tmp == NULL) ... else of y*/
  /* End of cleaning variable y */
  /* End of cleaning variable k */
  /* End of cleaning variable ier */
  } /*if (f2py_success) of lnew*/
  /* End of cleaning variable lnew */
  if((PyObject *)capi_x_tmp!=x_capi) {
    Py_XDECREF(capi_x_tmp); }
  }  /*if (capi_x_tmp == NULL) ... else of x*/
  /* End of cleaning variable x */
  } /*if (f2py_success) of nst*/
  /* End of cleaning variable nst */
/*end of cleanupfrompyobj*/
  if (capi_buildvalue == NULL) {
/*routdebugfailure*/
  } else {
/*routdebugleave*/
  }
  CFUNCSMESS("Freeing memory.\n");
/*freemem*/
#ifdef F2PY_REPORT_ATEXIT
f2py_stop_clock();
#endif
  return capi_buildvalue;
}
/******************************* end of addnod *******************************/

/********************************* arc_cosine *********************************/
static char doc_f2py_rout__stripack_arc_cosine[] = "\
arc_cosine = arc_cosine(c)\n\nWrapper for ``arc_cosine``.\
\n\nParameters\n----------\n"
"c : input float\n"
"\nReturns\n-------\n"
"arc_cosine : float";
/* extern void F_WRAPPEDFUNC_US(arc_cosine,ARC_COSINE)(double*,double*); */
static PyObject *f2py_rout__stripack_arc_cosine(const PyObject *capi_self,
                           PyObject *capi_args,
                           PyObject *capi_keywds,
                           void (*f2py_func)(double*,double*)) {
  PyObject * volatile capi_buildvalue = NULL;
  volatile int f2py_success = 1;
/*decl*/

  double arc_cosine = 0;
  double c = 0;
  PyObject *c_capi = Py_None;
  static char *capi_kwlist[] = {"c",NULL};

/*routdebugenter*/
#ifdef F2PY_REPORT_ATEXIT
f2py_start_clock();
#endif
  if (!PyArg_ParseTupleAndKeywords(capi_args,capi_keywds,\
    "O:_stripack.arc_cosine",\
    capi_kwlist,&c_capi))
    return NULL;
/*frompyobj*/
  /* Processing variable c */
    f2py_success = double_from_pyobj(&c,c_capi,"_stripack.arc_cosine() 1st argument (c) can't be converted to double");
  if (f2py_success) {
  /* Processing variable arc_cosine */
/*end of frompyobj*/
#ifdef F2PY_REPORT_ATEXIT
f2py_start_call_clock();
#endif
/*callfortranroutine*/
  (*f2py_func)(&arc_cosine,&c);
if (PyErr_Occurred())
  f2py_success = 0;
#ifdef F2PY_REPORT_ATEXIT
f2py_stop_call_clock();
#endif
/*end of callfortranroutine*/
    if (f2py_success) {
/*pyobjfrom*/
/*end of pyobjfrom*/
    CFUNCSMESS("Building return value.\n");
    capi_buildvalue = Py_BuildValue("d",arc_cosine);
/*closepyobjfrom*/
/*end of closepyobjfrom*/
    } /*if (f2py_success) after callfortranroutine*/
/*cleanupfrompyobj*/
  /* End of cleaning variable arc_cosine */
  } /*if (f2py_success) of c*/
  /* End of cleaning variable c */
/*end of cleanupfrompyobj*/
  if (capi_buildvalue == NULL) {
/*routdebugfailure*/
  } else {
/*routdebugleave*/
  }
  CFUNCSMESS("Freeing memory.\n");
/*freemem*/
#ifdef F2PY_REPORT_ATEXIT
f2py_stop_clock();
#endif
  return capi_buildvalue;
}
/***************************** end of arc_cosine *****************************/

/*********************************** areas ***********************************/
static char doc_f2py_rout__stripack_areas[] = "\
areas = areas(v1,v2,v3)\n\nWrapper for ``areas``.\
\n\nParameters\n----------\n"
"v1 : input rank-1 array('d') with bounds (3)\n"
"v2 : input rank-1 array('d') with bounds (3)\n"
"v3 : input rank-1 array('d') with bounds (3)\n"
"\nReturns\n-------\n"
"areas : float";
/* extern void F_WRAPPEDFUNC(areas,AREAS)(double*,double*,double*,double*); */
static PyObject *f2py_rout__stripack_areas(const PyObject *capi_self,
                           PyObject *capi_args,
                           PyObject *capi_keywds,
                           void (*f2py_func)(double*,double*,double*,double*)) {
  PyObject * volatile capi_buildvalue = NULL;
  volatile int f2py_success = 1;
/*decl*/

  double areas = 0;
  double *v1 = NULL;
  npy_intp v1_Dims[1] = {-1};
  const int v1_Rank = 1;
  PyArrayObject *capi_v1_tmp = NULL;
  int capi_v1_intent = 0;
  PyObject *v1_capi = Py_None;
  double *v2 = NULL;
  npy_intp v2_Dims[1] = {-1};
  const int v2_Rank = 1;
  PyArrayObject *capi_v2_tmp = NULL;
  int capi_v2_intent = 0;
  PyObject *v2_capi = Py_None;
  double *v3 = NULL;
  npy_intp v3_Dims[1] = {-1};
  const int v3_Rank = 1;
  PyArrayObject *capi_v3_tmp = NULL;
  int capi_v3_intent = 0;
  PyObject *v3_capi = Py_None;
  static char *capi_kwlist[] = {"v1","v2","v3",NULL};

/*routdebugenter*/
#ifdef F2PY_REPORT_ATEXIT
f2py_start_clock();
#endif
  if (!PyArg_ParseTupleAndKeywords(capi_args,capi_keywds,\
    "OOO:_stripack.areas",\
    capi_kwlist,&v1_capi,&v2_capi,&v3_capi))
    return NULL;
/*frompyobj*/
  /* Processing variable v1 */
  v1_Dims[0]=3;
  capi_v1_intent |= F2PY_INTENT_IN;
  capi_v1_tmp = array_from_pyobj(NPY_DOUBLE,v1_Dims,v1_Rank,capi_v1_intent,v1_capi);
  if (capi_v1_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 1st argument `v1' of _stripack.areas to C/Fortran array" );
  } else {
    v1 = (double *)(PyArray_DATA(capi_v1_tmp));

  /* Processing variable v2 */
  v2_Dims[0]=3;
  capi_v2_intent |= F2PY_INTENT_IN;
  capi_v2_tmp = array_from_pyobj(NPY_DOUBLE,v2_Dims,v2_Rank,capi_v2_intent,v2_capi);
  if (capi_v2_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 2nd argument `v2' of _stripack.areas to C/Fortran array" );
  } else {
    v2 = (double *)(PyArray_DATA(capi_v2_tmp));

  /* Processing variable v3 */
  v3_Dims[0]=3;
  capi_v3_intent |= F2PY_INTENT_IN;
  capi_v3_tmp = array_from_pyobj(NPY_DOUBLE,v3_Dims,v3_Rank,capi_v3_intent,v3_capi);
  if (capi_v3_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 3rd argument `v3' of _stripack.areas to C/Fortran array" );
  } else {
    v3 = (double *)(PyArray_DATA(capi_v3_tmp));

  /* Processing variable areas */
/*end of frompyobj*/
#ifdef F2PY_REPORT_ATEXIT
f2py_start_call_clock();
#endif
/*callfortranroutine*/
  (*f2py_func)(&areas,v1,v2,v3);
if (PyErr_Occurred())
  f2py_success = 0;
#ifdef F2PY_REPORT_ATEXIT
f2py_stop_call_clock();
#endif
/*end of callfortranroutine*/
    if (f2py_success) {
/*pyobjfrom*/
/*end of pyobjfrom*/
    CFUNCSMESS("Building return value.\n");
    capi_buildvalue = Py_BuildValue("d",areas);
/*closepyobjfrom*/
/*end of closepyobjfrom*/
    } /*if (f2py_success) after callfortranroutine*/
/*cleanupfrompyobj*/
  /* End of cleaning variable areas */
  if((PyObject *)capi_v3_tmp!=v3_capi) {
    Py_XDECREF(capi_v3_tmp); }
  }  /*if (capi_v3_tmp == NULL) ... else of v3*/
  /* End of cleaning variable v3 */
  if((PyObject *)capi_v2_tmp!=v2_capi) {
    Py_XDECREF(capi_v2_tmp); }
  }  /*if (capi_v2_tmp == NULL) ... else of v2*/
  /* End of cleaning variable v2 */
  if((PyObject *)capi_v1_tmp!=v1_capi) {
    Py_XDECREF(capi_v1_tmp); }
  }  /*if (capi_v1_tmp == NULL) ... else of v1*/
  /* End of cleaning variable v1 */
/*end of cleanupfrompyobj*/
  if (capi_buildvalue == NULL) {
/*routdebugfailure*/
  } else {
/*routdebugleave*/
  }
  CFUNCSMESS("Freeing memory.\n");
/*freemem*/
#ifdef F2PY_REPORT_ATEXIT
f2py_stop_clock();
#endif
  return capi_buildvalue;
}
/******************************** end of areas ********************************/

/********************************** triareas **********************************/
static char doc_f2py_rout__stripack_triareas[] = "\
triarea = triareas(x,y,z,triangles)\n\nWrapper for ``triareas``.\
\n\nParameters\n----------\n"
"x : input rank-1 array('d') with bounds (n)\n"
"y : input rank-1 array('d') with bounds (n)\n"
"z : input rank-1 array('d') with bounds (n)\n"
"triangles : input rank-2 array('i') with bounds (3,nt)\n"
"\nReturns\n-------\n"
"triarea : rank-1 array('d') with bounds (nt)";
/* extern void F_FUNC(triareas,TRIAREAS)(int*,double*,double*,double*,int*,int*,double*); */
static PyObject *f2py_rout__stripack_triareas(const PyObject *capi_self,
                           PyObject *capi_args,
                           PyObject *capi_keywds,
                           void (*f2py_func)(int*,double*,double*,double*,int*,int*,double*)) {
  PyObject * volatile capi_buildvalue = NULL;
  volatile int f2py_success = 1;
/*decl*/

  int n = 0;
  double *x = NULL;
  npy_intp x_Dims[1] = {-1};
  const int x_Rank = 1;
  PyArrayObject *capi_x_tmp = NULL;
  int capi_x_intent = 0;
  PyObject *x_capi = Py_None;
  double *y = NULL;
  npy_intp y_Dims[1] = {-1};
  const int y_Rank = 1;
  PyArrayObject *capi_y_tmp = NULL;
  int capi_y_intent = 0;
  PyObject *y_capi = Py_None;
  double *z = NULL;
  npy_intp z_Dims[1] = {-1};
  const int z_Rank = 1;
  PyArrayObject *capi_z_tmp = NULL;
  int capi_z_intent = 0;
  PyObject *z_capi = Py_None;
  int nt = 0;
  int *triangles = NULL;
  npy_intp triangles_Dims[2] = {-1, -1};
  const int triangles_Rank = 2;
  PyArrayObject *capi_triangles_tmp = NULL;
  int capi_triangles_intent = 0;
  PyObject *triangles_capi = Py_None;
  double *triarea = NULL;
  npy_intp triarea_Dims[1] = {-1};
  const int triarea_Rank = 1;
  PyArrayObject *capi_triarea_tmp = NULL;
  int capi_triarea_intent = 0;
  static char *capi_kwlist[] = {"x","y","z","triangles",NULL};

/*routdebugenter*/
#ifdef F2PY_REPORT_ATEXIT
f2py_start_clock();
#endif
  if (!PyArg_ParseTupleAndKeywords(capi_args,capi_keywds,\
    "OOOO:_stripack.triareas",\
    capi_kwlist,&x_capi,&y_capi,&z_capi,&triangles_capi))
    return NULL;
/*frompyobj*/
  /* Processing variable x */
  ;
  capi_x_intent |= F2PY_INTENT_IN;
  capi_x_tmp = array_from_pyobj(NPY_DOUBLE,x_Dims,x_Rank,capi_x_intent,x_capi);
  if (capi_x_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 1st argument `x' of _stripack.triareas to C/Fortran array" );
  } else {
    x = (double *)(PyArray_DATA(capi_x_tmp));

  /* Processing variable triangles */
  triangles_Dims[0]=3;
  capi_triangles_intent |= F2PY_INTENT_IN;
  capi_triangles_tmp = array_from_pyobj(NPY_INT,triangles_Dims,triangles_Rank,capi_triangles_intent,triangles_capi);
  if (capi_triangles_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 4th argument `triangles' of _stripack.triareas to C/Fortran array" );
  } else {
    triangles = (int *)(PyArray_DATA(capi_triangles_tmp));

  /* Processing variable n */
  n = len(x);
  /* Processing variable y */
  y_Dims[0]=n;
  capi_y_intent |= F2PY_INTENT_IN;
  capi_y_tmp = array_from_pyobj(NPY_DOUBLE,y_Dims,y_Rank,capi_y_intent,y_capi);
  if (capi_y_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 2nd argument `y' of _stripack.triareas to C/Fortran array" );
  } else {
    y = (double *)(PyArray_DATA(capi_y_tmp));

  /* Processing variable z */
  z_Dims[0]=n;
  capi_z_intent |= F2PY_INTENT_IN;
  capi_z_tmp = array_from_pyobj(NPY_DOUBLE,z_Dims,z_Rank,capi_z_intent,z_capi);
  if (capi_z_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 3rd argument `z' of _stripack.triareas to C/Fortran array" );
  } else {
    z = (double *)(PyArray_DATA(capi_z_tmp));

  /* Processing variable nt */
  nt = shape(triangles,1);
  /* Processing variable triarea */
  triarea_Dims[0]=nt;
  capi_triarea_intent |= F2PY_INTENT_OUT|F2PY_INTENT_HIDE;
  capi_triarea_tmp = array_from_pyobj(NPY_DOUBLE,triarea_Dims,triarea_Rank,capi_triarea_intent,Py_None);
  if (capi_triarea_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting hidden `triarea' of _stripack.triareas to C/Fortran array" );
  } else {
    triarea = (double *)(PyArray_DATA(capi_triarea_tmp));

/*end of frompyobj*/
#ifdef F2PY_REPORT_ATEXIT
f2py_start_call_clock();
#endif
/*callfortranroutine*/
        (*f2py_func)(&n,x,y,z,&nt,triangles,triarea);
if (PyErr_Occurred())
  f2py_success = 0;
#ifdef F2PY_REPORT_ATEXIT
f2py_stop_call_clock();
#endif
/*end of callfortranroutine*/
    if (f2py_success) {
/*pyobjfrom*/
/*end of pyobjfrom*/
    CFUNCSMESS("Building return value.\n");
    capi_buildvalue = Py_BuildValue("N",capi_triarea_tmp);
/*closepyobjfrom*/
/*end of closepyobjfrom*/
    } /*if (f2py_success) after callfortranroutine*/
/*cleanupfrompyobj*/
  }  /*if (capi_triarea_tmp == NULL) ... else of triarea*/
  /* End of cleaning variable triarea */
  /* End of cleaning variable nt */
  if((PyObject *)capi_z_tmp!=z_capi) {
    Py_XDECREF(capi_z_tmp); }
  }  /*if (capi_z_tmp == NULL) ... else of z*/
  /* End of cleaning variable z */
  if((PyObject *)capi_y_tmp!=y_capi) {
    Py_XDECREF(capi_y_tmp); }
  }  /*if (capi_y_tmp == NULL) ... else of y*/
  /* End of cleaning variable y */
  /* End of cleaning variable n */
  if((PyObject *)capi_triangles_tmp!=triangles_capi) {
    Py_XDECREF(capi_triangles_tmp); }
  }  /*if (capi_triangles_tmp == NULL) ... else of triangles*/
  /* End of cleaning variable triangles */
  if((PyObject *)capi_x_tmp!=x_capi) {
    Py_XDECREF(capi_x_tmp); }
  }  /*if (capi_x_tmp == NULL) ... else of x*/
  /* End of cleaning variable x */
/*end of cleanupfrompyobj*/
  if (capi_buildvalue == NULL) {
/*routdebugfailure*/
  } else {
/*routdebugleave*/
  }
  CFUNCSMESS("Freeing memory.\n");
/*freemem*/
#ifdef F2PY_REPORT_ATEXIT
f2py_stop_clock();
#endif
  return capi_buildvalue;
}
/****************************** end of triareas ******************************/

/*********************************** bnodes ***********************************/
static char doc_f2py_rout__stripack_bnodes[] = "\
nb,na,nt = bnodes(list,lptr,lend,nodes)\n\nWrapper for ``bnodes``.\
\n\nParameters\n----------\n"
"list : input rank-1 array('i') with bounds (6 * n - 12)\n"
"lptr : input rank-1 array('i') with bounds (6 * n - 12)\n"
"lend : input rank-1 array('i') with bounds (n)\n"
"nodes : input rank-1 array('i') with bounds (n)\n"
"\nReturns\n-------\n"
"nb : int\n"
"na : int\n"
"nt : int";
/* extern void F_FUNC(bnodes,BNODES)(int*,int*,int*,int*,int*,int*,int*,int*); */
static PyObject *f2py_rout__stripack_bnodes(const PyObject *capi_self,
                           PyObject *capi_args,
                           PyObject *capi_keywds,
                           void (*f2py_func)(int*,int*,int*,int*,int*,int*,int*,int*)) {
  PyObject * volatile capi_buildvalue = NULL;
  volatile int f2py_success = 1;
/*decl*/

  int n = 0;
  int *list = NULL;
  npy_intp list_Dims[1] = {-1};
  const int list_Rank = 1;
  PyArrayObject *capi_list_tmp = NULL;
  int capi_list_intent = 0;
  PyObject *list_capi = Py_None;
  int *lptr = NULL;
  npy_intp lptr_Dims[1] = {-1};
  const int lptr_Rank = 1;
  PyArrayObject *capi_lptr_tmp = NULL;
  int capi_lptr_intent = 0;
  PyObject *lptr_capi = Py_None;
  int *lend = NULL;
  npy_intp lend_Dims[1] = {-1};
  const int lend_Rank = 1;
  PyArrayObject *capi_lend_tmp = NULL;
  int capi_lend_intent = 0;
  PyObject *lend_capi = Py_None;
  int *nodes = NULL;
  npy_intp nodes_Dims[1] = {-1};
  const int nodes_Rank = 1;
  PyArrayObject *capi_nodes_tmp = NULL;
  int capi_nodes_intent = 0;
  PyObject *nodes_capi = Py_None;
  int nb = 0;
  int na = 0;
  int nt = 0;
  static char *capi_kwlist[] = {"list","lptr","lend","nodes",NULL};

/*routdebugenter*/
#ifdef F2PY_REPORT_ATEXIT
f2py_start_clock();
#endif
  if (!PyArg_ParseTupleAndKeywords(capi_args,capi_keywds,\
    "OOOO:_stripack.bnodes",\
    capi_kwlist,&list_capi,&lptr_capi,&lend_capi,&nodes_capi))
    return NULL;
/*frompyobj*/
  /* Processing variable lend */
  ;
  capi_lend_intent |= F2PY_INTENT_IN;
  capi_lend_tmp = array_from_pyobj(NPY_INT,lend_Dims,lend_Rank,capi_lend_intent,lend_capi);
  if (capi_lend_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 3rd argument `lend' of _stripack.bnodes to C/Fortran array" );
  } else {
    lend = (int *)(PyArray_DATA(capi_lend_tmp));

  /* Processing variable nb */
  /* Processing variable na */
  /* Processing variable nt */
  /* Processing variable n */
  n = len(lend);
  /* Processing variable list */
  list_Dims[0]=6 * n - 12;
  capi_list_intent |= F2PY_INTENT_IN;
  capi_list_tmp = array_from_pyobj(NPY_INT,list_Dims,list_Rank,capi_list_intent,list_capi);
  if (capi_list_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 1st argument `list' of _stripack.bnodes to C/Fortran array" );
  } else {
    list = (int *)(PyArray_DATA(capi_list_tmp));

  /* Processing variable lptr */
  lptr_Dims[0]=6 * n - 12;
  capi_lptr_intent |= F2PY_INTENT_IN;
  capi_lptr_tmp = array_from_pyobj(NPY_INT,lptr_Dims,lptr_Rank,capi_lptr_intent,lptr_capi);
  if (capi_lptr_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 2nd argument `lptr' of _stripack.bnodes to C/Fortran array" );
  } else {
    lptr = (int *)(PyArray_DATA(capi_lptr_tmp));

  /* Processing variable nodes */
  nodes_Dims[0]=n;
  capi_nodes_intent |= F2PY_INTENT_IN;
  capi_nodes_tmp = array_from_pyobj(NPY_INT,nodes_Dims,nodes_Rank,capi_nodes_intent,nodes_capi);
  if (capi_nodes_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 4th argument `nodes' of _stripack.bnodes to C/Fortran array" );
  } else {
    nodes = (int *)(PyArray_DATA(capi_nodes_tmp));

/*end of frompyobj*/
#ifdef F2PY_REPORT_ATEXIT
f2py_start_call_clock();
#endif
/*callfortranroutine*/
        (*f2py_func)(&n,list,lptr,lend,nodes,&nb,&na,&nt);
if (PyErr_Occurred())
  f2py_success = 0;
#ifdef F2PY_REPORT_ATEXIT
f2py_stop_call_clock();
#endif
/*end of callfortranroutine*/
    if (f2py_success) {
/*pyobjfrom*/
/*end of pyobjfrom*/
    CFUNCSMESS("Building return value.\n");
    capi_buildvalue = Py_BuildValue("iii",nb,na,nt);
/*closepyobjfrom*/
/*end of closepyobjfrom*/
    } /*if (f2py_success) after callfortranroutine*/
/*cleanupfrompyobj*/
  if((PyObject *)capi_nodes_tmp!=nodes_capi) {
    Py_XDECREF(capi_nodes_tmp); }
  }  /*if (capi_nodes_tmp == NULL) ... else of nodes*/
  /* End of cleaning variable nodes */
  if((PyObject *)capi_lptr_tmp!=lptr_capi) {
    Py_XDECREF(capi_lptr_tmp); }
  }  /*if (capi_lptr_tmp == NULL) ... else of lptr*/
  /* End of cleaning variable lptr */
  if((PyObject *)capi_list_tmp!=list_capi) {
    Py_XDECREF(capi_list_tmp); }
  }  /*if (capi_list_tmp == NULL) ... else of list*/
  /* End of cleaning variable list */
  /* End of cleaning variable n */
  /* End of cleaning variable nt */
  /* End of cleaning variable na */
  /* End of cleaning variable nb */
  if((PyObject *)capi_lend_tmp!=lend_capi) {
    Py_XDECREF(capi_lend_tmp); }
  }  /*if (capi_lend_tmp == NULL) ... else of lend*/
  /* End of cleaning variable lend */
/*end of cleanupfrompyobj*/
  if (capi_buildvalue == NULL) {
/*routdebugfailure*/
  } else {
/*routdebugleave*/
  }
  CFUNCSMESS("Freeing memory.\n");
/*freemem*/
#ifdef F2PY_REPORT_ATEXIT
f2py_stop_clock();
#endif
  return capi_buildvalue;
}
/******************************* end of bnodes *******************************/

/*********************************** circum ***********************************/
static char doc_f2py_rout__stripack_circum[] = "\
c,ier = circum(v1,v2,v3)\n\nWrapper for ``circum``.\
\n\nParameters\n----------\n"
"v1 : input rank-1 array('d') with bounds (3)\n"
"v2 : input rank-1 array('d') with bounds (3)\n"
"v3 : input rank-1 array('d') with bounds (3)\n"
"\nReturns\n-------\n"
"c : rank-1 array('d') with bounds (3)\n"
"ier : int";
/* extern void F_FUNC(circum,CIRCUM)(double*,double*,double*,double*,int*); */
static PyObject *f2py_rout__stripack_circum(const PyObject *capi_self,
                           PyObject *capi_args,
                           PyObject *capi_keywds,
                           void (*f2py_func)(double*,double*,double*,double*,int*)) {
  PyObject * volatile capi_buildvalue = NULL;
  volatile int f2py_success = 1;
/*decl*/

  double *v1 = NULL;
  npy_intp v1_Dims[1] = {-1};
  const int v1_Rank = 1;
  PyArrayObject *capi_v1_tmp = NULL;
  int capi_v1_intent = 0;
  PyObject *v1_capi = Py_None;
  double *v2 = NULL;
  npy_intp v2_Dims[1] = {-1};
  const int v2_Rank = 1;
  PyArrayObject *capi_v2_tmp = NULL;
  int capi_v2_intent = 0;
  PyObject *v2_capi = Py_None;
  double *v3 = NULL;
  npy_intp v3_Dims[1] = {-1};
  const int v3_Rank = 1;
  PyArrayObject *capi_v3_tmp = NULL;
  int capi_v3_intent = 0;
  PyObject *v3_capi = Py_None;
  double *c = NULL;
  npy_intp c_Dims[1] = {-1};
  const int c_Rank = 1;
  PyArrayObject *capi_c_tmp = NULL;
  int capi_c_intent = 0;
  int ier = 0;
  static char *capi_kwlist[] = {"v1","v2","v3",NULL};

/*routdebugenter*/
#ifdef F2PY_REPORT_ATEXIT
f2py_start_clock();
#endif
  if (!PyArg_ParseTupleAndKeywords(capi_args,capi_keywds,\
    "OOO:_stripack.circum",\
    capi_kwlist,&v1_capi,&v2_capi,&v3_capi))
    return NULL;
/*frompyobj*/
  /* Processing variable v1 */
  v1_Dims[0]=3;
  capi_v1_intent |= F2PY_INTENT_IN;
  capi_v1_tmp = array_from_pyobj(NPY_DOUBLE,v1_Dims,v1_Rank,capi_v1_intent,v1_capi);
  if (capi_v1_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 1st argument `v1' of _stripack.circum to C/Fortran array" );
  } else {
    v1 = (double *)(PyArray_DATA(capi_v1_tmp));

  /* Processing variable v2 */
  v2_Dims[0]=3;
  capi_v2_intent |= F2PY_INTENT_IN;
  capi_v2_tmp = array_from_pyobj(NPY_DOUBLE,v2_Dims,v2_Rank,capi_v2_intent,v2_capi);
  if (capi_v2_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 2nd argument `v2' of _stripack.circum to C/Fortran array" );
  } else {
    v2 = (double *)(PyArray_DATA(capi_v2_tmp));

  /* Processing variable v3 */
  v3_Dims[0]=3;
  capi_v3_intent |= F2PY_INTENT_IN;
  capi_v3_tmp = array_from_pyobj(NPY_DOUBLE,v3_Dims,v3_Rank,capi_v3_intent,v3_capi);
  if (capi_v3_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 3rd argument `v3' of _stripack.circum to C/Fortran array" );
  } else {
    v3 = (double *)(PyArray_DATA(capi_v3_tmp));

  /* Processing variable c */
  c_Dims[0]=3;
  capi_c_intent |= F2PY_INTENT_OUT|F2PY_INTENT_HIDE;
  capi_c_tmp = array_from_pyobj(NPY_DOUBLE,c_Dims,c_Rank,capi_c_intent,Py_None);
  if (capi_c_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting hidden `c' of _stripack.circum to C/Fortran array" );
  } else {
    c = (double *)(PyArray_DATA(capi_c_tmp));

  /* Processing variable ier */
/*end of frompyobj*/
#ifdef F2PY_REPORT_ATEXIT
f2py_start_call_clock();
#endif
/*callfortranroutine*/
        (*f2py_func)(v1,v2,v3,c,&ier);
if (PyErr_Occurred())
  f2py_success = 0;
#ifdef F2PY_REPORT_ATEXIT
f2py_stop_call_clock();
#endif
/*end of callfortranroutine*/
    if (f2py_success) {
/*pyobjfrom*/
/*end of pyobjfrom*/
    CFUNCSMESS("Building return value.\n");
    capi_buildvalue = Py_BuildValue("Ni",capi_c_tmp,ier);
/*closepyobjfrom*/
/*end of closepyobjfrom*/
    } /*if (f2py_success) after callfortranroutine*/
/*cleanupfrompyobj*/
  /* End of cleaning variable ier */
  }  /*if (capi_c_tmp == NULL) ... else of c*/
  /* End of cleaning variable c */
  if((PyObject *)capi_v3_tmp!=v3_capi) {
    Py_XDECREF(capi_v3_tmp); }
  }  /*if (capi_v3_tmp == NULL) ... else of v3*/
  /* End of cleaning variable v3 */
  if((PyObject *)capi_v2_tmp!=v2_capi) {
    Py_XDECREF(capi_v2_tmp); }
  }  /*if (capi_v2_tmp == NULL) ... else of v2*/
  /* End of cleaning variable v2 */
  if((PyObject *)capi_v1_tmp!=v1_capi) {
    Py_XDECREF(capi_v1_tmp); }
  }  /*if (capi_v1_tmp == NULL) ... else of v1*/
  /* End of cleaning variable v1 */
/*end of cleanupfrompyobj*/
  if (capi_buildvalue == NULL) {
/*routdebugfailure*/
  } else {
/*routdebugleave*/
  }
  CFUNCSMESS("Freeing memory.\n");
/*freemem*/
#ifdef F2PY_REPORT_ATEXIT
f2py_stop_clock();
#endif
  return capi_buildvalue;
}
/******************************* end of circum *******************************/

/*********************************** crlist ***********************************/
static char doc_f2py_rout__stripack_crlist[] = "\
lptr,lnew,ltri,listc,nb,xc,yc,zc,rc,ier = crlist(ncol,x,y,z,list,lend,lptr,lnew)\n\nWrapper for ``crlist``.\
\n\nParameters\n----------\n"
"ncol : input int\n"
"x : input rank-1 array('d') with bounds (n)\n"
"y : input rank-1 array('d') with bounds (n)\n"
"z : input rank-1 array('d') with bounds (n)\n"
"list : input rank-1 array('i') with bounds (6 * n - 12)\n"
"lend : input rank-1 array('i') with bounds (n)\n"
"lptr : input rank-1 array('i') with bounds (6 * n - 12)\n"
"lnew : input int\n"
"\nReturns\n-------\n"
"lptr : rank-1 array('i') with bounds (6 * n - 12)\n"
"lnew : int\n"
"ltri : rank-2 array('i') with bounds (6,ncol)\n"
"listc : rank-1 array('i') with bounds (6 * n - 12)\n"
"nb : int\n"
"xc : rank-1 array('d') with bounds (2 * n - 4)\n"
"yc : rank-1 array('d') with bounds (2 * n - 4)\n"
"zc : rank-1 array('d') with bounds (2 * n - 4)\n"
"rc : rank-1 array('d') with bounds (2 * n - 4)\n"
"ier : int";
/* extern void F_FUNC(crlist,CRLIST)(int*,int*,double*,double*,double*,int*,int*,int*,int*,int*,int*,int*,double*,double*,double*,double*,int*); */
static PyObject *f2py_rout__stripack_crlist(const PyObject *capi_self,
                           PyObject *capi_args,
                           PyObject *capi_keywds,
                           void (*f2py_func)(int*,int*,double*,double*,double*,int*,int*,int*,int*,int*,int*,int*,double*,double*,double*,double*,int*)) {
  PyObject * volatile capi_buildvalue = NULL;
  volatile int f2py_success = 1;
/*decl*/

  int n = 0;
  int ncol = 0;
  PyObject *ncol_capi = Py_None;
  double *x = NULL;
  npy_intp x_Dims[1] = {-1};
  const int x_Rank = 1;
  PyArrayObject *capi_x_tmp = NULL;
  int capi_x_intent = 0;
  PyObject *x_capi = Py_None;
  double *y = NULL;
  npy_intp y_Dims[1] = {-1};
  const int y_Rank = 1;
  PyArrayObject *capi_y_tmp = NULL;
  int capi_y_intent = 0;
  PyObject *y_capi = Py_None;
  double *z = NULL;
  npy_intp z_Dims[1] = {-1};
  const int z_Rank = 1;
  PyArrayObject *capi_z_tmp = NULL;
  int capi_z_intent = 0;
  PyObject *z_capi = Py_None;
  int *list = NULL;
  npy_intp list_Dims[1] = {-1};
  const int list_Rank = 1;
  PyArrayObject *capi_list_tmp = NULL;
  int capi_list_intent = 0;
  PyObject *list_capi = Py_None;
  int *lend = NULL;
  npy_intp lend_Dims[1] = {-1};
  const int lend_Rank = 1;
  PyArrayObject *capi_lend_tmp = NULL;
  int capi_lend_intent = 0;
  PyObject *lend_capi = Py_None;
  int *lptr = NULL;
  npy_intp lptr_Dims[1] = {-1};
  const int lptr_Rank = 1;
  PyArrayObject *capi_lptr_tmp = NULL;
  int capi_lptr_intent = 0;
  PyObject *lptr_capi = Py_None;
  int lnew = 0;
  PyObject *lnew_capi = Py_None;
  int *ltri = NULL;
  npy_intp ltri_Dims[2] = {-1, -1};
  const int ltri_Rank = 2;
  PyArrayObject *capi_ltri_tmp = NULL;
  int capi_ltri_intent = 0;
  int *listc = NULL;
  npy_intp listc_Dims[1] = {-1};
  const int listc_Rank = 1;
  PyArrayObject *capi_listc_tmp = NULL;
  int capi_listc_intent = 0;
  int nb = 0;
  double *xc = NULL;
  npy_intp xc_Dims[1] = {-1};
  const int xc_Rank = 1;
  PyArrayObject *capi_xc_tmp = NULL;
  int capi_xc_intent = 0;
  double *yc = NULL;
  npy_intp yc_Dims[1] = {-1};
  const int yc_Rank = 1;
  PyArrayObject *capi_yc_tmp = NULL;
  int capi_yc_intent = 0;
  double *zc = NULL;
  npy_intp zc_Dims[1] = {-1};
  const int zc_Rank = 1;
  PyArrayObject *capi_zc_tmp = NULL;
  int capi_zc_intent = 0;
  double *rc = NULL;
  npy_intp rc_Dims[1] = {-1};
  const int rc_Rank = 1;
  PyArrayObject *capi_rc_tmp = NULL;
  int capi_rc_intent = 0;
  int ier = 0;
  static char *capi_kwlist[] = {"ncol","x","y","z","list","lend","lptr","lnew",NULL};

/*routdebugenter*/
#ifdef F2PY_REPORT_ATEXIT
f2py_start_clock();
#endif
  if (!PyArg_ParseTupleAndKeywords(capi_args,capi_keywds,\
    "OOOOOOOO:_stripack.crlist",\
    capi_kwlist,&ncol_capi,&x_capi,&y_capi,&z_capi,&list_capi,&lend_capi,&lptr_capi,&lnew_capi))
    return NULL;
/*frompyobj*/
  /* Processing variable ncol */
    f2py_success = int_from_pyobj(&ncol,ncol_capi,"_stripack.crlist() 1st argument (ncol) can't be converted to int");
  if (f2py_success) {
  /* Processing variable x */
  ;
  capi_x_intent |= F2PY_INTENT_IN;
  capi_x_tmp = array_from_pyobj(NPY_DOUBLE,x_Dims,x_Rank,capi_x_intent,x_capi);
  if (capi_x_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 2nd argument `x' of _stripack.crlist to C/Fortran array" );
  } else {
    x = (double *)(PyArray_DATA(capi_x_tmp));

  /* Processing variable lnew */
    f2py_success = int_from_pyobj(&lnew,lnew_capi,"_stripack.crlist() 8th argument (lnew) can't be converted to int");
  if (f2py_success) {
  /* Processing variable nb */
  /* Processing variable ier */
  /* Processing variable n */
  n = len(x);
  /* Processing variable y */
  y_Dims[0]=n;
  capi_y_intent |= F2PY_INTENT_IN;
  capi_y_tmp = array_from_pyobj(NPY_DOUBLE,y_Dims,y_Rank,capi_y_intent,y_capi);
  if (capi_y_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 3rd argument `y' of _stripack.crlist to C/Fortran array" );
  } else {
    y = (double *)(PyArray_DATA(capi_y_tmp));

  /* Processing variable z */
  z_Dims[0]=n;
  capi_z_intent |= F2PY_INTENT_IN;
  capi_z_tmp = array_from_pyobj(NPY_DOUBLE,z_Dims,z_Rank,capi_z_intent,z_capi);
  if (capi_z_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 4th argument `z' of _stripack.crlist to C/Fortran array" );
  } else {
    z = (double *)(PyArray_DATA(capi_z_tmp));

  /* Processing variable list */
  list_Dims[0]=6 * n - 12;
  capi_list_intent |= F2PY_INTENT_IN;
  capi_list_tmp = array_from_pyobj(NPY_INT,list_Dims,list_Rank,capi_list_intent,list_capi);
  if (capi_list_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 5th argument `list' of _stripack.crlist to C/Fortran array" );
  } else {
    list = (int *)(PyArray_DATA(capi_list_tmp));

  /* Processing variable lend */
  lend_Dims[0]=n;
  capi_lend_intent |= F2PY_INTENT_IN;
  capi_lend_tmp = array_from_pyobj(NPY_INT,lend_Dims,lend_Rank,capi_lend_intent,lend_capi);
  if (capi_lend_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 6th argument `lend' of _stripack.crlist to C/Fortran array" );
  } else {
    lend = (int *)(PyArray_DATA(capi_lend_tmp));

  /* Processing variable lptr */
  lptr_Dims[0]=6 * n - 12;
  capi_lptr_intent |= F2PY_INTENT_IN|F2PY_INTENT_OUT;
  capi_lptr_tmp = array_from_pyobj(NPY_INT,lptr_Dims,lptr_Rank,capi_lptr_intent,lptr_capi);
  if (capi_lptr_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 7th argument `lptr' of _stripack.crlist to C/Fortran array" );
  } else {
    lptr = (int *)(PyArray_DATA(capi_lptr_tmp));

  /* Processing variable ltri */
  ltri_Dims[0]=6,ltri_Dims[1]=ncol;
  capi_ltri_intent |= F2PY_INTENT_OUT|F2PY_INTENT_HIDE;
  capi_ltri_tmp = array_from_pyobj(NPY_INT,ltri_Dims,ltri_Rank,capi_ltri_intent,Py_None);
  if (capi_ltri_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting hidden `ltri' of _stripack.crlist to C/Fortran array" );
  } else {
    ltri = (int *)(PyArray_DATA(capi_ltri_tmp));

  /* Processing variable listc */
  listc_Dims[0]=6 * n - 12;
  capi_listc_intent |= F2PY_INTENT_OUT|F2PY_INTENT_HIDE;
  capi_listc_tmp = array_from_pyobj(NPY_INT,listc_Dims,listc_Rank,capi_listc_intent,Py_None);
  if (capi_listc_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting hidden `listc' of _stripack.crlist to C/Fortran array" );
  } else {
    listc = (int *)(PyArray_DATA(capi_listc_tmp));

  /* Processing variable xc */
  xc_Dims[0]=2 * n - 4;
  capi_xc_intent |= F2PY_INTENT_OUT|F2PY_INTENT_HIDE;
  capi_xc_tmp = array_from_pyobj(NPY_DOUBLE,xc_Dims,xc_Rank,capi_xc_intent,Py_None);
  if (capi_xc_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting hidden `xc' of _stripack.crlist to C/Fortran array" );
  } else {
    xc = (double *)(PyArray_DATA(capi_xc_tmp));

  /* Processing variable yc */
  yc_Dims[0]=2 * n - 4;
  capi_yc_intent |= F2PY_INTENT_OUT|F2PY_INTENT_HIDE;
  capi_yc_tmp = array_from_pyobj(NPY_DOUBLE,yc_Dims,yc_Rank,capi_yc_intent,Py_None);
  if (capi_yc_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting hidden `yc' of _stripack.crlist to C/Fortran array" );
  } else {
    yc = (double *)(PyArray_DATA(capi_yc_tmp));

  /* Processing variable zc */
  zc_Dims[0]=2 * n - 4;
  capi_zc_intent |= F2PY_INTENT_OUT|F2PY_INTENT_HIDE;
  capi_zc_tmp = array_from_pyobj(NPY_DOUBLE,zc_Dims,zc_Rank,capi_zc_intent,Py_None);
  if (capi_zc_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting hidden `zc' of _stripack.crlist to C/Fortran array" );
  } else {
    zc = (double *)(PyArray_DATA(capi_zc_tmp));

  /* Processing variable rc */
  rc_Dims[0]=2 * n - 4;
  capi_rc_intent |= F2PY_INTENT_OUT|F2PY_INTENT_HIDE;
  capi_rc_tmp = array_from_pyobj(NPY_DOUBLE,rc_Dims,rc_Rank,capi_rc_intent,Py_None);
  if (capi_rc_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting hidden `rc' of _stripack.crlist to C/Fortran array" );
  } else {
    rc = (double *)(PyArray_DATA(capi_rc_tmp));

/*end of frompyobj*/
#ifdef F2PY_REPORT_ATEXIT
f2py_start_call_clock();
#endif
/*callfortranroutine*/
        (*f2py_func)(&n,&ncol,x,y,z,list,lend,lptr,&lnew,ltri,listc,&nb,xc,yc,zc,rc,&ier);
if (PyErr_Occurred())
  f2py_success = 0;
#ifdef F2PY_REPORT_ATEXIT
f2py_stop_call_clock();
#endif
/*end of callfortranroutine*/
    if (f2py_success) {
/*pyobjfrom*/
/*end of pyobjfrom*/
    CFUNCSMESS("Building return value.\n");
    capi_buildvalue = Py_BuildValue("NiNNiNNNNi",capi_lptr_tmp,lnew,capi_ltri_tmp,capi_listc_tmp,nb,capi_xc_tmp,capi_yc_tmp,capi_zc_tmp,capi_rc_tmp,ier);
/*closepyobjfrom*/
/*end of closepyobjfrom*/
    } /*if (f2py_success) after callfortranroutine*/
/*cleanupfrompyobj*/
  }  /*if (capi_rc_tmp == NULL) ... else of rc*/
  /* End of cleaning variable rc */
  }  /*if (capi_zc_tmp == NULL) ... else of zc*/
  /* End of cleaning variable zc */
  }  /*if (capi_yc_tmp == NULL) ... else of yc*/
  /* End of cleaning variable yc */
  }  /*if (capi_xc_tmp == NULL) ... else of xc*/
  /* End of cleaning variable xc */
  }  /*if (capi_listc_tmp == NULL) ... else of listc*/
  /* End of cleaning variable listc */
  }  /*if (capi_ltri_tmp == NULL) ... else of ltri*/
  /* End of cleaning variable ltri */
  }  /*if (capi_lptr_tmp == NULL) ... else of lptr*/
  /* End of cleaning variable lptr */
  if((PyObject *)capi_lend_tmp!=lend_capi) {
    Py_XDECREF(capi_lend_tmp); }
  }  /*if (capi_lend_tmp == NULL) ... else of lend*/
  /* End of cleaning variable lend */
  if((PyObject *)capi_list_tmp!=list_capi) {
    Py_XDECREF(capi_list_tmp); }
  }  /*if (capi_list_tmp == NULL) ... else of list*/
  /* End of cleaning variable list */
  if((PyObject *)capi_z_tmp!=z_capi) {
    Py_XDECREF(capi_z_tmp); }
  }  /*if (capi_z_tmp == NULL) ... else of z*/
  /* End of cleaning variable z */
  if((PyObject *)capi_y_tmp!=y_capi) {
    Py_XDECREF(capi_y_tmp); }
  }  /*if (capi_y_tmp == NULL) ... else of y*/
  /* End of cleaning variable y */
  /* End of cleaning variable n */
  /* End of cleaning variable ier */
  /* End of cleaning variable nb */
  } /*if (f2py_success) of lnew*/
  /* End of cleaning variable lnew */
  if((PyObject *)capi_x_tmp!=x_capi) {
    Py_XDECREF(capi_x_tmp); }
  }  /*if (capi_x_tmp == NULL) ... else of x*/
  /* End of cleaning variable x */
  } /*if (f2py_success) of ncol*/
  /* End of cleaning variable ncol */
/*end of cleanupfrompyobj*/
  if (capi_buildvalue == NULL) {
/*routdebugfailure*/
  } else {
/*routdebugleave*/
  }
  CFUNCSMESS("Freeing memory.\n");
/*freemem*/
#ifdef F2PY_REPORT_ATEXIT
f2py_stop_clock();
#endif
  return capi_buildvalue;
}
/******************************* end of crlist *******************************/

/*********************************** delarc ***********************************/
static char doc_f2py_rout__stripack_delarc[] = "\
list,lptr,lend,lnew,ier = delarc(io1,io2,list,lptr,lend,lnew)\n\nWrapper for ``delarc``.\
\n\nParameters\n----------\n"
"io1 : input int\n"
"io2 : input int\n"
"list : input rank-1 array('i') with bounds (6 * n - 12)\n"
"lptr : input rank-1 array('i') with bounds (6 * n - 12)\n"
"lend : input rank-1 array('i') with bounds (n)\n"
"lnew : input int\n"
"\nReturns\n-------\n"
"list : rank-1 array('i') with bounds (6 * n - 12)\n"
"lptr : rank-1 array('i') with bounds (6 * n - 12)\n"
"lend : rank-1 array('i') with bounds (n)\n"
"lnew : int\n"
"ier : int";
/* extern void F_FUNC(delarc,DELARC)(int*,int*,int*,int*,int*,int*,int*,int*); */
static PyObject *f2py_rout__stripack_delarc(const PyObject *capi_self,
                           PyObject *capi_args,
                           PyObject *capi_keywds,
                           void (*f2py_func)(int*,int*,int*,int*,int*,int*,int*,int*)) {
  PyObject * volatile capi_buildvalue = NULL;
  volatile int f2py_success = 1;
/*decl*/

  int n = 0;
  int io1 = 0;
  PyObject *io1_capi = Py_None;
  int io2 = 0;
  PyObject *io2_capi = Py_None;
  int *list = NULL;
  npy_intp list_Dims[1] = {-1};
  const int list_Rank = 1;
  PyArrayObject *capi_list_tmp = NULL;
  int capi_list_intent = 0;
  PyObject *list_capi = Py_None;
  int *lptr = NULL;
  npy_intp lptr_Dims[1] = {-1};
  const int lptr_Rank = 1;
  PyArrayObject *capi_lptr_tmp = NULL;
  int capi_lptr_intent = 0;
  PyObject *lptr_capi = Py_None;
  int *lend = NULL;
  npy_intp lend_Dims[1] = {-1};
  const int lend_Rank = 1;
  PyArrayObject *capi_lend_tmp = NULL;
  int capi_lend_intent = 0;
  PyObject *lend_capi = Py_None;
  int lnew = 0;
  PyObject *lnew_capi = Py_None;
  int ier = 0;
  static char *capi_kwlist[] = {"io1","io2","list","lptr","lend","lnew",NULL};

/*routdebugenter*/
#ifdef F2PY_REPORT_ATEXIT
f2py_start_clock();
#endif
  if (!PyArg_ParseTupleAndKeywords(capi_args,capi_keywds,\
    "OOOOOO:_stripack.delarc",\
    capi_kwlist,&io1_capi,&io2_capi,&list_capi,&lptr_capi,&lend_capi,&lnew_capi))
    return NULL;
/*frompyobj*/
  /* Processing variable io1 */
    f2py_success = int_from_pyobj(&io1,io1_capi,"_stripack.delarc() 1st argument (io1) can't be converted to int");
  if (f2py_success) {
  /* Processing variable io2 */
    f2py_success = int_from_pyobj(&io2,io2_capi,"_stripack.delarc() 2nd argument (io2) can't be converted to int");
  if (f2py_success) {
  /* Processing variable lend */
  ;
  capi_lend_intent |= F2PY_INTENT_IN|F2PY_INTENT_OUT;
  capi_lend_tmp = array_from_pyobj(NPY_INT,lend_Dims,lend_Rank,capi_lend_intent,lend_capi);
  if (capi_lend_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 5th argument `lend' of _stripack.delarc to C/Fortran array" );
  } else {
    lend = (int *)(PyArray_DATA(capi_lend_tmp));

  /* Processing variable lnew */
    f2py_success = int_from_pyobj(&lnew,lnew_capi,"_stripack.delarc() 6th argument (lnew) can't be converted to int");
  if (f2py_success) {
  /* Processing variable ier */
  /* Processing variable n */
  n = len(lend);
  /* Processing variable list */
  list_Dims[0]=6 * n - 12;
  capi_list_intent |= F2PY_INTENT_IN|F2PY_INTENT_OUT;
  capi_list_tmp = array_from_pyobj(NPY_INT,list_Dims,list_Rank,capi_list_intent,list_capi);
  if (capi_list_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 3rd argument `list' of _stripack.delarc to C/Fortran array" );
  } else {
    list = (int *)(PyArray_DATA(capi_list_tmp));

  /* Processing variable lptr */
  lptr_Dims[0]=6 * n - 12;
  capi_lptr_intent |= F2PY_INTENT_IN|F2PY_INTENT_OUT;
  capi_lptr_tmp = array_from_pyobj(NPY_INT,lptr_Dims,lptr_Rank,capi_lptr_intent,lptr_capi);
  if (capi_lptr_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 4th argument `lptr' of _stripack.delarc to C/Fortran array" );
  } else {
    lptr = (int *)(PyArray_DATA(capi_lptr_tmp));

/*end of frompyobj*/
#ifdef F2PY_REPORT_ATEXIT
f2py_start_call_clock();
#endif
/*callfortranroutine*/
        (*f2py_func)(&n,&io1,&io2,list,lptr,lend,&lnew,&ier);
if (PyErr_Occurred())
  f2py_success = 0;
#ifdef F2PY_REPORT_ATEXIT
f2py_stop_call_clock();
#endif
/*end of callfortranroutine*/
    if (f2py_success) {
/*pyobjfrom*/
/*end of pyobjfrom*/
    CFUNCSMESS("Building return value.\n");
    capi_buildvalue = Py_BuildValue("NNNii",capi_list_tmp,capi_lptr_tmp,capi_lend_tmp,lnew,ier);
/*closepyobjfrom*/
/*end of closepyobjfrom*/
    } /*if (f2py_success) after callfortranroutine*/
/*cleanupfrompyobj*/
  }  /*if (capi_lptr_tmp == NULL) ... else of lptr*/
  /* End of cleaning variable lptr */
  }  /*if (capi_list_tmp == NULL) ... else of list*/
  /* End of cleaning variable list */
  /* End of cleaning variable n */
  /* End of cleaning variable ier */
  } /*if (f2py_success) of lnew*/
  /* End of cleaning variable lnew */
  }  /*if (capi_lend_tmp == NULL) ... else of lend*/
  /* End of cleaning variable lend */
  } /*if (f2py_success) of io2*/
  /* End of cleaning variable io2 */
  } /*if (f2py_success) of io1*/
  /* End of cleaning variable io1 */
/*end of cleanupfrompyobj*/
  if (capi_buildvalue == NULL) {
/*routdebugfailure*/
  } else {
/*routdebugleave*/
  }
  CFUNCSMESS("Freeing memory.\n");
/*freemem*/
#ifdef F2PY_REPORT_ATEXIT
f2py_stop_clock();
#endif
  return capi_buildvalue;
}
/******************************* end of delarc *******************************/

/*********************************** delnod ***********************************/
static char doc_f2py_rout__stripack_delnod[] = "\
x,y,z,list,lptr,lend,lnew,lwk,iwk,ier = delnod(k,x,y,z,list,lptr,lend,lnew,iwk,[lwk])\n\nWrapper for ``delnod``.\
\n\nParameters\n----------\n"
"k : input int\n"
"x : input rank-1 array('d') with bounds (n)\n"
"y : input rank-1 array('d') with bounds (n)\n"
"z : input rank-1 array('d') with bounds (n)\n"
"list : input rank-1 array('i') with bounds (6 * n - 12)\n"
"lptr : input rank-1 array('i') with bounds (6 * n - 12)\n"
"lend : input rank-1 array('i') with bounds (n)\n"
"lnew : input int\n"
"iwk : input rank-2 array('i') with bounds (2,lwk)\n"
"\nOther Parameters\n----------------\n"
"lwk : input int, optional\n    Default: shape(iwk,1)\n"
"\nReturns\n-------\n"
"x : rank-1 array('d') with bounds (n)\n"
"y : rank-1 array('d') with bounds (n)\n"
"z : rank-1 array('d') with bounds (n)\n"
"list : rank-1 array('i') with bounds (6 * n - 12)\n"
"lptr : rank-1 array('i') with bounds (6 * n - 12)\n"
"lend : rank-1 array('i') with bounds (n)\n"
"lnew : int\n"
"lwk : int\n"
"iwk : rank-2 array('i') with bounds (2,lwk)\n"
"ier : int";
/* extern void F_FUNC(delnod,DELNOD)(int*,int*,double*,double*,double*,int*,int*,int*,int*,int*,int*,int*); */
static PyObject *f2py_rout__stripack_delnod(const PyObject *capi_self,
                           PyObject *capi_args,
                           PyObject *capi_keywds,
                           void (*f2py_func)(int*,int*,double*,double*,double*,int*,int*,int*,int*,int*,int*,int*)) {
  PyObject * volatile capi_buildvalue = NULL;
  volatile int f2py_success = 1;
/*decl*/

  int k = 0;
  PyObject *k_capi = Py_None;
  int n = 0;
  double *x = NULL;
  npy_intp x_Dims[1] = {-1};
  const int x_Rank = 1;
  PyArrayObject *capi_x_tmp = NULL;
  int capi_x_intent = 0;
  PyObject *x_capi = Py_None;
  double *y = NULL;
  npy_intp y_Dims[1] = {-1};
  const int y_Rank = 1;
  PyArrayObject *capi_y_tmp = NULL;
  int capi_y_intent = 0;
  PyObject *y_capi = Py_None;
  double *z = NULL;
  npy_intp z_Dims[1] = {-1};
  const int z_Rank = 1;
  PyArrayObject *capi_z_tmp = NULL;
  int capi_z_intent = 0;
  PyObject *z_capi = Py_None;
  int *list = NULL;
  npy_intp list_Dims[1] = {-1};
  const int list_Rank = 1;
  PyArrayObject *capi_list_tmp = NULL;
  int capi_list_intent = 0;
  PyObject *list_capi = Py_None;
  int *lptr = NULL;
  npy_intp lptr_Dims[1] = {-1};
  const int lptr_Rank = 1;
  PyArrayObject *capi_lptr_tmp = NULL;
  int capi_lptr_intent = 0;
  PyObject *lptr_capi = Py_None;
  int *lend = NULL;
  npy_intp lend_Dims[1] = {-1};
  const int lend_Rank = 1;
  PyArrayObject *capi_lend_tmp = NULL;
  int capi_lend_intent = 0;
  PyObject *lend_capi = Py_None;
  int lnew = 0;
  PyObject *lnew_capi = Py_None;
  int lwk = 0;
  PyObject *lwk_capi = Py_None;
  int *iwk = NULL;
  npy_intp iwk_Dims[2] = {-1, -1};
  const int iwk_Rank = 2;
  PyArrayObject *capi_iwk_tmp = NULL;
  int capi_iwk_intent = 0;
  PyObject *iwk_capi = Py_None;
  int ier = 0;
  static char *capi_kwlist[] = {"k","x","y","z","list","lptr","lend","lnew","iwk","lwk",NULL};

/*routdebugenter*/
#ifdef F2PY_REPORT_ATEXIT
f2py_start_clock();
#endif
  if (!PyArg_ParseTupleAndKeywords(capi_args,capi_keywds,\
    "OOOOOOOOO|O:_stripack.delnod",\
    capi_kwlist,&k_capi,&x_capi,&y_capi,&z_capi,&list_capi,&lptr_capi,&lend_capi,&lnew_capi,&iwk_capi,&lwk_capi))
    return NULL;
/*frompyobj*/
  /* Processing variable k */
    f2py_success = int_from_pyobj(&k,k_capi,"_stripack.delnod() 1st argument (k) can't be converted to int");
  if (f2py_success) {
  /* Processing variable x */
  ;
  capi_x_intent |= F2PY_INTENT_IN|F2PY_INTENT_OUT;
  capi_x_tmp = array_from_pyobj(NPY_DOUBLE,x_Dims,x_Rank,capi_x_intent,x_capi);
  if (capi_x_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 2nd argument `x' of _stripack.delnod to C/Fortran array" );
  } else {
    x = (double *)(PyArray_DATA(capi_x_tmp));

  /* Processing variable lnew */
    f2py_success = int_from_pyobj(&lnew,lnew_capi,"_stripack.delnod() 8th argument (lnew) can't be converted to int");
  if (f2py_success) {
  /* Processing variable iwk */
  iwk_Dims[0]=2;
  capi_iwk_intent |= F2PY_INTENT_IN|F2PY_INTENT_OUT;
  capi_iwk_tmp = array_from_pyobj(NPY_INT,iwk_Dims,iwk_Rank,capi_iwk_intent,iwk_capi);
  if (capi_iwk_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 9th argument `iwk' of _stripack.delnod to C/Fortran array" );
  } else {
    iwk = (int *)(PyArray_DATA(capi_iwk_tmp));

  /* Processing variable ier */
  /* Processing variable n */
  n = len(x);
  /* Processing variable y */
  y_Dims[0]=n;
  capi_y_intent |= F2PY_INTENT_IN|F2PY_INTENT_OUT;
  capi_y_tmp = array_from_pyobj(NPY_DOUBLE,y_Dims,y_Rank,capi_y_intent,y_capi);
  if (capi_y_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 3rd argument `y' of _stripack.delnod to C/Fortran array" );
  } else {
    y = (double *)(PyArray_DATA(capi_y_tmp));

  /* Processing variable z */
  z_Dims[0]=n;
  capi_z_intent |= F2PY_INTENT_IN|F2PY_INTENT_OUT;
  capi_z_tmp = array_from_pyobj(NPY_DOUBLE,z_Dims,z_Rank,capi_z_intent,z_capi);
  if (capi_z_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 4th argument `z' of _stripack.delnod to C/Fortran array" );
  } else {
    z = (double *)(PyArray_DATA(capi_z_tmp));

  /* Processing variable list */
  list_Dims[0]=6 * n - 12;
  capi_list_intent |= F2PY_INTENT_IN|F2PY_INTENT_OUT;
  capi_list_tmp = array_from_pyobj(NPY_INT,list_Dims,list_Rank,capi_list_intent,list_capi);
  if (capi_list_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 5th argument `list' of _stripack.delnod to C/Fortran array" );
  } else {
    list = (int *)(PyArray_DATA(capi_list_tmp));

  /* Processing variable lptr */
  lptr_Dims[0]=6 * n - 12;
  capi_lptr_intent |= F2PY_INTENT_IN|F2PY_INTENT_OUT;
  capi_lptr_tmp = array_from_pyobj(NPY_INT,lptr_Dims,lptr_Rank,capi_lptr_intent,lptr_capi);
  if (capi_lptr_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 6th argument `lptr' of _stripack.delnod to C/Fortran array" );
  } else {
    lptr = (int *)(PyArray_DATA(capi_lptr_tmp));

  /* Processing variable lend */
  lend_Dims[0]=n;
  capi_lend_intent |= F2PY_INTENT_IN|F2PY_INTENT_OUT;
  capi_lend_tmp = array_from_pyobj(NPY_INT,lend_Dims,lend_Rank,capi_lend_intent,lend_capi);
  if (capi_lend_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 7th argument `lend' of _stripack.delnod to C/Fortran array" );
  } else {
    lend = (int *)(PyArray_DATA(capi_lend_tmp));

  /* Processing variable lwk */
  if (lwk_capi == Py_None) lwk = shape(iwk,1); else
    f2py_success = int_from_pyobj(&lwk,lwk_capi,"_stripack.delnod() 1st keyword (lwk) can't be converted to int");
  if (f2py_success) {
  CHECKSCALAR(shape(iwk,1)==lwk,"shape(iwk,1)==lwk","1st keyword lwk","delnod:lwk=%d",lwk) {
/*end of frompyobj*/
#ifdef F2PY_REPORT_ATEXIT
f2py_start_call_clock();
#endif
/*callfortranroutine*/
        (*f2py_func)(&k,&n,x,y,z,list,lptr,lend,&lnew,&lwk,iwk,&ier);
if (PyErr_Occurred())
  f2py_success = 0;
#ifdef F2PY_REPORT_ATEXIT
f2py_stop_call_clock();
#endif
/*end of callfortranroutine*/
    if (f2py_success) {
/*pyobjfrom*/
/*end of pyobjfrom*/
    CFUNCSMESS("Building return value.\n");
    capi_buildvalue = Py_BuildValue("NNNNNNiiNi",capi_x_tmp,capi_y_tmp,capi_z_tmp,capi_list_tmp,capi_lptr_tmp,capi_lend_tmp,lnew,lwk,capi_iwk_tmp,ier);
/*closepyobjfrom*/
/*end of closepyobjfrom*/
    } /*if (f2py_success) after callfortranroutine*/
/*cleanupfrompyobj*/
  } /*CHECKSCALAR(shape(iwk,1)==lwk)*/
  } /*if (f2py_success) of lwk*/
  /* End of cleaning variable lwk */
  }  /*if (capi_lend_tmp == NULL) ... else of lend*/
  /* End of cleaning variable lend */
  }  /*if (capi_lptr_tmp == NULL) ... else of lptr*/
  /* End of cleaning variable lptr */
  }  /*if (capi_list_tmp == NULL) ... else of list*/
  /* End of cleaning variable list */
  }  /*if (capi_z_tmp == NULL) ... else of z*/
  /* End of cleaning variable z */
  }  /*if (capi_y_tmp == NULL) ... else of y*/
  /* End of cleaning variable y */
  /* End of cleaning variable n */
  /* End of cleaning variable ier */
  }  /*if (capi_iwk_tmp == NULL) ... else of iwk*/
  /* End of cleaning variable iwk */
  } /*if (f2py_success) of lnew*/
  /* End of cleaning variable lnew */
  }  /*if (capi_x_tmp == NULL) ... else of x*/
  /* End of cleaning variable x */
  } /*if (f2py_success) of k*/
  /* End of cleaning variable k */
/*end of cleanupfrompyobj*/
  if (capi_buildvalue == NULL) {
/*routdebugfailure*/
  } else {
/*routdebugleave*/
  }
  CFUNCSMESS("Freeing memory.\n");
/*freemem*/
#ifdef F2PY_REPORT_ATEXIT
f2py_stop_clock();
#endif
  return capi_buildvalue;
}
/******************************* end of delnod *******************************/

/************************************ edge ************************************/
static char doc_f2py_rout__stripack_edge[] = "\
lwk,iwk,list,lptr,lend,ier = edge(in1,in2,x,y,z,lwk,list,lptr,lend)\n\nWrapper for ``edge``.\
\n\nParameters\n----------\n"
"in1 : input int\n"
"in2 : input int\n"
"x : input rank-1 array('d') with bounds (len(lend))\n"
"y : input rank-1 array('d') with bounds (len(lend))\n"
"z : input rank-1 array('d') with bounds (len(lend))\n"
"lwk : input int\n"
"list : input rank-1 array('i') with bounds (6*len(x)-12)\n"
"lptr : input rank-1 array('i') with bounds (6*len(x)-12)\n"
"lend : input rank-1 array('i') with bounds (len(x))\n"
"\nReturns\n-------\n"
"lwk : int\n"
"iwk : rank-2 array('i') with bounds (2,lwk)\n"
"list : rank-1 array('i') with bounds (6*len(x)-12)\n"
"lptr : rank-1 array('i') with bounds (6*len(x)-12)\n"
"lend : rank-1 array('i') with bounds (len(x))\n"
"ier : int";
/* extern void F_FUNC(edge,EDGE)(int*,int*,double*,double*,double*,int*,int*,int*,int*,int*,int*); */
static PyObject *f2py_rout__stripack_edge(const PyObject *capi_self,
                           PyObject *capi_args,
                           PyObject *capi_keywds,
                           void (*f2py_func)(int*,int*,double*,double*,double*,int*,int*,int*,int*,int*,int*)) {
  PyObject * volatile capi_buildvalue = NULL;
  volatile int f2py_success = 1;
/*decl*/

  int in1 = 0;
  PyObject *in1_capi = Py_None;
  int in2 = 0;
  PyObject *in2_capi = Py_None;
  double *x = NULL;
  npy_intp x_Dims[1] = {-1};
  const int x_Rank = 1;
  PyArrayObject *capi_x_tmp = NULL;
  int capi_x_intent = 0;
  PyObject *x_capi = Py_None;
  double *y = NULL;
  npy_intp y_Dims[1] = {-1};
  const int y_Rank = 1;
  PyArrayObject *capi_y_tmp = NULL;
  int capi_y_intent = 0;
  PyObject *y_capi = Py_None;
  double *z = NULL;
  npy_intp z_Dims[1] = {-1};
  const int z_Rank = 1;
  PyArrayObject *capi_z_tmp = NULL;
  int capi_z_intent = 0;
  PyObject *z_capi = Py_None;
  int lwk = 0;
  PyObject *lwk_capi = Py_None;
  int *iwk = NULL;
  npy_intp iwk_Dims[2] = {-1, -1};
  const int iwk_Rank = 2;
  PyArrayObject *capi_iwk_tmp = NULL;
  int capi_iwk_intent = 0;
  int *list = NULL;
  npy_intp list_Dims[1] = {-1};
  const int list_Rank = 1;
  PyArrayObject *capi_list_tmp = NULL;
  int capi_list_intent = 0;
  PyObject *list_capi = Py_None;
  int *lptr = NULL;
  npy_intp lptr_Dims[1] = {-1};
  const int lptr_Rank = 1;
  PyArrayObject *capi_lptr_tmp = NULL;
  int capi_lptr_intent = 0;
  PyObject *lptr_capi = Py_None;
  int *lend = NULL;
  npy_intp lend_Dims[1] = {-1};
  const int lend_Rank = 1;
  PyArrayObject *capi_lend_tmp = NULL;
  int capi_lend_intent = 0;
  PyObject *lend_capi = Py_None;
  int ier = 0;
  static char *capi_kwlist[] = {"in1","in2","x","y","z","lwk","list","lptr","lend",NULL};

/*routdebugenter*/
#ifdef F2PY_REPORT_ATEXIT
f2py_start_clock();
#endif
  if (!PyArg_ParseTupleAndKeywords(capi_args,capi_keywds,\
    "OOOOOOOOO:_stripack.edge",\
    capi_kwlist,&in1_capi,&in2_capi,&x_capi,&y_capi,&z_capi,&lwk_capi,&list_capi,&lptr_capi,&lend_capi))
    return NULL;
/*frompyobj*/
  /* Processing variable in1 */
    f2py_success = int_from_pyobj(&in1,in1_capi,"_stripack.edge() 1st argument (in1) can't be converted to int");
  if (f2py_success) {
  /* Processing variable in2 */
    f2py_success = int_from_pyobj(&in2,in2_capi,"_stripack.edge() 2nd argument (in2) can't be converted to int");
  if (f2py_success) {
  /* Processing variable lwk */
    f2py_success = int_from_pyobj(&lwk,lwk_capi,"_stripack.edge() 6th argument (lwk) can't be converted to int");
  if (f2py_success) {
  /* Processing variable ier */
  /* Processing variable iwk */
  iwk_Dims[0]=2,iwk_Dims[1]=lwk;
  capi_iwk_intent |= F2PY_INTENT_OUT|F2PY_INTENT_HIDE;
  capi_iwk_tmp = array_from_pyobj(NPY_INT,iwk_Dims,iwk_Rank,capi_iwk_intent,Py_None);
  if (capi_iwk_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting hidden `iwk' of _stripack.edge to C/Fortran array" );
  } else {
    iwk = (int *)(PyArray_DATA(capi_iwk_tmp));

  /* Processing variable lptr */
  ;
  capi_lptr_intent |= F2PY_INTENT_IN|F2PY_INTENT_OUT;
  capi_lptr_tmp = array_from_pyobj(NPY_INT,lptr_Dims,lptr_Rank,capi_lptr_intent,lptr_capi);
  if (capi_lptr_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 8th argument `lptr' of _stripack.edge to C/Fortran array" );
  } else {
    lptr = (int *)(PyArray_DATA(capi_lptr_tmp));

  /* Processing variable lend */
  ;
  capi_lend_intent |= F2PY_INTENT_IN|F2PY_INTENT_OUT;
  capi_lend_tmp = array_from_pyobj(NPY_INT,lend_Dims,lend_Rank,capi_lend_intent,lend_capi);
  if (capi_lend_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 9th argument `lend' of _stripack.edge to C/Fortran array" );
  } else {
    lend = (int *)(PyArray_DATA(capi_lend_tmp));

  /* Processing variable x */
  x_Dims[0]=len(lend);
  capi_x_intent |= F2PY_INTENT_IN;
  capi_x_tmp = array_from_pyobj(NPY_DOUBLE,x_Dims,x_Rank,capi_x_intent,x_capi);
  if (capi_x_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 3rd argument `x' of _stripack.edge to C/Fortran array" );
  } else {
    x = (double *)(PyArray_DATA(capi_x_tmp));

  /* Processing variable y */
  y_Dims[0]=len(lend);
  capi_y_intent |= F2PY_INTENT_IN;
  capi_y_tmp = array_from_pyobj(NPY_DOUBLE,y_Dims,y_Rank,capi_y_intent,y_capi);
  if (capi_y_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 4th argument `y' of _stripack.edge to C/Fortran array" );
  } else {
    y = (double *)(PyArray_DATA(capi_y_tmp));

  /* Processing variable z */
  z_Dims[0]=len(lend);
  capi_z_intent |= F2PY_INTENT_IN;
  capi_z_tmp = array_from_pyobj(NPY_DOUBLE,z_Dims,z_Rank,capi_z_intent,z_capi);
  if (capi_z_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 5th argument `z' of _stripack.edge to C/Fortran array" );
  } else {
    z = (double *)(PyArray_DATA(capi_z_tmp));

  /* Processing variable list */
  list_Dims[0]=6*len(x)-12;
  capi_list_intent |= F2PY_INTENT_IN|F2PY_INTENT_OUT;
  capi_list_tmp = array_from_pyobj(NPY_INT,list_Dims,list_Rank,capi_list_intent,list_capi);
  if (capi_list_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 7th argument `list' of _stripack.edge to C/Fortran array" );
  } else {
    list = (int *)(PyArray_DATA(capi_list_tmp));

/*end of frompyobj*/
#ifdef F2PY_REPORT_ATEXIT
f2py_start_call_clock();
#endif
/*callfortranroutine*/
        (*f2py_func)(&in1,&in2,x,y,z,&lwk,iwk,list,lptr,lend,&ier);
if (PyErr_Occurred())
  f2py_success = 0;
#ifdef F2PY_REPORT_ATEXIT
f2py_stop_call_clock();
#endif
/*end of callfortranroutine*/
    if (f2py_success) {
/*pyobjfrom*/
/*end of pyobjfrom*/
    CFUNCSMESS("Building return value.\n");
    capi_buildvalue = Py_BuildValue("iNNNNi",lwk,capi_iwk_tmp,capi_list_tmp,capi_lptr_tmp,capi_lend_tmp,ier);
/*closepyobjfrom*/
/*end of closepyobjfrom*/
    } /*if (f2py_success) after callfortranroutine*/
/*cleanupfrompyobj*/
  }  /*if (capi_list_tmp == NULL) ... else of list*/
  /* End of cleaning variable list */
  if((PyObject *)capi_z_tmp!=z_capi) {
    Py_XDECREF(capi_z_tmp); }
  }  /*if (capi_z_tmp == NULL) ... else of z*/
  /* End of cleaning variable z */
  if((PyObject *)capi_y_tmp!=y_capi) {
    Py_XDECREF(capi_y_tmp); }
  }  /*if (capi_y_tmp == NULL) ... else of y*/
  /* End of cleaning variable y */
  if((PyObject *)capi_x_tmp!=x_capi) {
    Py_XDECREF(capi_x_tmp); }
  }  /*if (capi_x_tmp == NULL) ... else of x*/
  /* End of cleaning variable x */
  }  /*if (capi_lend_tmp == NULL) ... else of lend*/
  /* End of cleaning variable lend */
  }  /*if (capi_lptr_tmp == NULL) ... else of lptr*/
  /* End of cleaning variable lptr */
  }  /*if (capi_iwk_tmp == NULL) ... else of iwk*/
  /* End of cleaning variable iwk */
  /* End of cleaning variable ier */
  } /*if (f2py_success) of lwk*/
  /* End of cleaning variable lwk */
  } /*if (f2py_success) of in2*/
  /* End of cleaning variable in2 */
  } /*if (f2py_success) of in1*/
  /* End of cleaning variable in1 */
/*end of cleanupfrompyobj*/
  if (capi_buildvalue == NULL) {
/*routdebugfailure*/
  } else {
/*routdebugleave*/
  }
  CFUNCSMESS("Freeing memory.\n");
/*freemem*/
#ifdef F2PY_REPORT_ATEXIT
f2py_stop_clock();
#endif
  return capi_buildvalue;
}
/******************************** end of edge ********************************/

/*********************************** nearnd ***********************************/
static char doc_f2py_rout__stripack_nearnd[] = "\
nearnd,al = nearnd(p,x,y,z,list,lptr,lend,[ist])\n\nWrapper for ``nearnd``.\
\n\nParameters\n----------\n"
"p : input rank-1 array('d') with bounds (3)\n"
"x : input rank-1 array('d') with bounds (n)\n"
"y : input rank-1 array('d') with bounds (n)\n"
"z : input rank-1 array('d') with bounds (n)\n"
"list : input rank-1 array('i') with bounds (6 * n - 12)\n"
"lptr : input rank-1 array('i') with bounds (6 * n - 12)\n"
"lend : input rank-1 array('i') with bounds (n)\n"
"\nOther Parameters\n----------------\n"
"ist : input int, optional\n    Default: 1\n"
"\nReturns\n-------\n"
"nearnd : int\n"
"al : float";
/* extern void F_WRAPPEDFUNC(nearnd,NEARND)(int*,double*,int*,int*,double*,double*,double*,int*,int*,int*,double*); */
static PyObject *f2py_rout__stripack_nearnd(const PyObject *capi_self,
                           PyObject *capi_args,
                           PyObject *capi_keywds,
                           void (*f2py_func)(int*,double*,int*,int*,double*,double*,double*,int*,int*,int*,double*)) {
  PyObject * volatile capi_buildvalue = NULL;
  volatile int f2py_success = 1;
/*decl*/

  int nearnd = 0;
  double *p = NULL;
  npy_intp p_Dims[1] = {-1};
  const int p_Rank = 1;
  PyArrayObject *capi_p_tmp = NULL;
  int capi_p_intent = 0;
  PyObject *p_capi = Py_None;
  int ist = 0;
  PyObject *ist_capi = Py_None;
  int n = 0;
  double *x = NULL;
  npy_intp x_Dims[1] = {-1};
  const int x_Rank = 1;
  PyArrayObject *capi_x_tmp = NULL;
  int capi_x_intent = 0;
  PyObject *x_capi = Py_None;
  double *y = NULL;
  npy_intp y_Dims[1] = {-1};
  const int y_Rank = 1;
  PyArrayObject *capi_y_tmp = NULL;
  int capi_y_intent = 0;
  PyObject *y_capi = Py_None;
  double *z = NULL;
  npy_intp z_Dims[1] = {-1};
  const int z_Rank = 1;
  PyArrayObject *capi_z_tmp = NULL;
  int capi_z_intent = 0;
  PyObject *z_capi = Py_None;
  int *list = NULL;
  npy_intp list_Dims[1] = {-1};
  const int list_Rank = 1;
  PyArrayObject *capi_list_tmp = NULL;
  int capi_list_intent = 0;
  PyObject *list_capi = Py_None;
  int *lptr = NULL;
  npy_intp lptr_Dims[1] = {-1};
  const int lptr_Rank = 1;
  PyArrayObject *capi_lptr_tmp = NULL;
  int capi_lptr_intent = 0;
  PyObject *lptr_capi = Py_None;
  int *lend = NULL;
  npy_intp lend_Dims[1] = {-1};
  const int lend_Rank = 1;
  PyArrayObject *capi_lend_tmp = NULL;
  int capi_lend_intent = 0;
  PyObject *lend_capi = Py_None;
  double al = 0;
  static char *capi_kwlist[] = {"p","x","y","z","list","lptr","lend","ist",NULL};

/*routdebugenter*/
#ifdef F2PY_REPORT_ATEXIT
f2py_start_clock();
#endif
  if (!PyArg_ParseTupleAndKeywords(capi_args,capi_keywds,\
    "OOOOOOO|O:_stripack.nearnd",\
    capi_kwlist,&p_capi,&x_capi,&y_capi,&z_capi,&list_capi,&lptr_capi,&lend_capi,&ist_capi))
    return NULL;
/*frompyobj*/
  /* Processing variable p */
  p_Dims[0]=3;
  capi_p_intent |= F2PY_INTENT_IN;
  capi_p_tmp = array_from_pyobj(NPY_DOUBLE,p_Dims,p_Rank,capi_p_intent,p_capi);
  if (capi_p_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 1st argument `p' of _stripack.nearnd to C/Fortran array" );
  } else {
    p = (double *)(PyArray_DATA(capi_p_tmp));

  /* Processing variable ist */
  if (ist_capi == Py_None) ist = 1; else
    f2py_success = int_from_pyobj(&ist,ist_capi,"_stripack.nearnd() 1st keyword (ist) can't be converted to int");
  if (f2py_success) {
  /* Processing variable x */
  ;
  capi_x_intent |= F2PY_INTENT_IN;
  capi_x_tmp = array_from_pyobj(NPY_DOUBLE,x_Dims,x_Rank,capi_x_intent,x_capi);
  if (capi_x_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 2nd argument `x' of _stripack.nearnd to C/Fortran array" );
  } else {
    x = (double *)(PyArray_DATA(capi_x_tmp));

  /* Processing variable al */
  /* Processing variable nearnd */
  /* Processing variable n */
  n = len(x);
  /* Processing variable y */
  y_Dims[0]=n;
  capi_y_intent |= F2PY_INTENT_IN;
  capi_y_tmp = array_from_pyobj(NPY_DOUBLE,y_Dims,y_Rank,capi_y_intent,y_capi);
  if (capi_y_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 3rd argument `y' of _stripack.nearnd to C/Fortran array" );
  } else {
    y = (double *)(PyArray_DATA(capi_y_tmp));

  /* Processing variable z */
  z_Dims[0]=n;
  capi_z_intent |= F2PY_INTENT_IN;
  capi_z_tmp = array_from_pyobj(NPY_DOUBLE,z_Dims,z_Rank,capi_z_intent,z_capi);
  if (capi_z_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 4th argument `z' of _stripack.nearnd to C/Fortran array" );
  } else {
    z = (double *)(PyArray_DATA(capi_z_tmp));

  /* Processing variable list */
  list_Dims[0]=6 * n - 12;
  capi_list_intent |= F2PY_INTENT_IN;
  capi_list_tmp = array_from_pyobj(NPY_INT,list_Dims,list_Rank,capi_list_intent,list_capi);
  if (capi_list_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 5th argument `list' of _stripack.nearnd to C/Fortran array" );
  } else {
    list = (int *)(PyArray_DATA(capi_list_tmp));

  /* Processing variable lptr */
  lptr_Dims[0]=6 * n - 12;
  capi_lptr_intent |= F2PY_INTENT_IN;
  capi_lptr_tmp = array_from_pyobj(NPY_INT,lptr_Dims,lptr_Rank,capi_lptr_intent,lptr_capi);
  if (capi_lptr_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 6th argument `lptr' of _stripack.nearnd to C/Fortran array" );
  } else {
    lptr = (int *)(PyArray_DATA(capi_lptr_tmp));

  /* Processing variable lend */
  lend_Dims[0]=n;
  capi_lend_intent |= F2PY_INTENT_IN;
  capi_lend_tmp = array_from_pyobj(NPY_INT,lend_Dims,lend_Rank,capi_lend_intent,lend_capi);
  if (capi_lend_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 7th argument `lend' of _stripack.nearnd to C/Fortran array" );
  } else {
    lend = (int *)(PyArray_DATA(capi_lend_tmp));

/*end of frompyobj*/
#ifdef F2PY_REPORT_ATEXIT
f2py_start_call_clock();
#endif
/*callfortranroutine*/
  (*f2py_func)(&nearnd,p,&ist,&n,x,y,z,list,lptr,lend,&al);
if (PyErr_Occurred())
  f2py_success = 0;
#ifdef F2PY_REPORT_ATEXIT
f2py_stop_call_clock();
#endif
/*end of callfortranroutine*/
    if (f2py_success) {
/*pyobjfrom*/
/*end of pyobjfrom*/
    CFUNCSMESS("Building return value.\n");
    capi_buildvalue = Py_BuildValue("id",nearnd,al);
/*closepyobjfrom*/
/*end of closepyobjfrom*/
    } /*if (f2py_success) after callfortranroutine*/
/*cleanupfrompyobj*/
  if((PyObject *)capi_lend_tmp!=lend_capi) {
    Py_XDECREF(capi_lend_tmp); }
  }  /*if (capi_lend_tmp == NULL) ... else of lend*/
  /* End of cleaning variable lend */
  if((PyObject *)capi_lptr_tmp!=lptr_capi) {
    Py_XDECREF(capi_lptr_tmp); }
  }  /*if (capi_lptr_tmp == NULL) ... else of lptr*/
  /* End of cleaning variable lptr */
  if((PyObject *)capi_list_tmp!=list_capi) {
    Py_XDECREF(capi_list_tmp); }
  }  /*if (capi_list_tmp == NULL) ... else of list*/
  /* End of cleaning variable list */
  if((PyObject *)capi_z_tmp!=z_capi) {
    Py_XDECREF(capi_z_tmp); }
  }  /*if (capi_z_tmp == NULL) ... else of z*/
  /* End of cleaning variable z */
  if((PyObject *)capi_y_tmp!=y_capi) {
    Py_XDECREF(capi_y_tmp); }
  }  /*if (capi_y_tmp == NULL) ... else of y*/
  /* End of cleaning variable y */
  /* End of cleaning variable n */
  /* End of cleaning variable nearnd */
  /* End of cleaning variable al */
  if((PyObject *)capi_x_tmp!=x_capi) {
    Py_XDECREF(capi_x_tmp); }
  }  /*if (capi_x_tmp == NULL) ... else of x*/
  /* End of cleaning variable x */
  } /*if (f2py_success) of ist*/
  /* End of cleaning variable ist */
  if((PyObject *)capi_p_tmp!=p_capi) {
    Py_XDECREF(capi_p_tmp); }
  }  /*if (capi_p_tmp == NULL) ... else of p*/
  /* End of cleaning variable p */
/*end of cleanupfrompyobj*/
  if (capi_buildvalue == NULL) {
/*routdebugfailure*/
  } else {
/*routdebugleave*/
  }
  CFUNCSMESS("Freeing memory.\n");
/*freemem*/
#ifdef F2PY_REPORT_ATEXIT
f2py_stop_clock();
#endif
  return capi_buildvalue;
}
/******************************* end of nearnd *******************************/

/*********************************** trans ***********************************/
static char doc_f2py_rout__stripack_trans[] = "\
x,y,z = trans(rlat,rlon)\n\nWrapper for ``trans``.\
\n\nParameters\n----------\n"
"rlat : input rank-1 array('d') with bounds (n)\n"
"rlon : input rank-1 array('d') with bounds (n)\n"
"\nReturns\n-------\n"
"x : rank-1 array('d') with bounds (n)\n"
"y : rank-1 array('d') with bounds (n)\n"
"z : rank-1 array('d') with bounds (n)";
/* extern void F_FUNC(trans,TRANS)(int*,double*,double*,double*,double*,double*); */
static PyObject *f2py_rout__stripack_trans(const PyObject *capi_self,
                           PyObject *capi_args,
                           PyObject *capi_keywds,
                           void (*f2py_func)(int*,double*,double*,double*,double*,double*)) {
  PyObject * volatile capi_buildvalue = NULL;
  volatile int f2py_success = 1;
/*decl*/

  int n = 0;
  double *rlat = NULL;
  npy_intp rlat_Dims[1] = {-1};
  const int rlat_Rank = 1;
  PyArrayObject *capi_rlat_tmp = NULL;
  int capi_rlat_intent = 0;
  PyObject *rlat_capi = Py_None;
  double *rlon = NULL;
  npy_intp rlon_Dims[1] = {-1};
  const int rlon_Rank = 1;
  PyArrayObject *capi_rlon_tmp = NULL;
  int capi_rlon_intent = 0;
  PyObject *rlon_capi = Py_None;
  double *x = NULL;
  npy_intp x_Dims[1] = {-1};
  const int x_Rank = 1;
  PyArrayObject *capi_x_tmp = NULL;
  int capi_x_intent = 0;
  double *y = NULL;
  npy_intp y_Dims[1] = {-1};
  const int y_Rank = 1;
  PyArrayObject *capi_y_tmp = NULL;
  int capi_y_intent = 0;
  double *z = NULL;
  npy_intp z_Dims[1] = {-1};
  const int z_Rank = 1;
  PyArrayObject *capi_z_tmp = NULL;
  int capi_z_intent = 0;
  static char *capi_kwlist[] = {"rlat","rlon",NULL};

/*routdebugenter*/
#ifdef F2PY_REPORT_ATEXIT
f2py_start_clock();
#endif
  if (!PyArg_ParseTupleAndKeywords(capi_args,capi_keywds,\
    "OO:_stripack.trans",\
    capi_kwlist,&rlat_capi,&rlon_capi))
    return NULL;
/*frompyobj*/
  /* Processing variable rlat */
  ;
  capi_rlat_intent |= F2PY_INTENT_IN;
  capi_rlat_tmp = array_from_pyobj(NPY_DOUBLE,rlat_Dims,rlat_Rank,capi_rlat_intent,rlat_capi);
  if (capi_rlat_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 1st argument `rlat' of _stripack.trans to C/Fortran array" );
  } else {
    rlat = (double *)(PyArray_DATA(capi_rlat_tmp));

  /* Processing variable n */
  n = len(rlat);
  /* Processing variable rlon */
  rlon_Dims[0]=n;
  capi_rlon_intent |= F2PY_INTENT_IN;
  capi_rlon_tmp = array_from_pyobj(NPY_DOUBLE,rlon_Dims,rlon_Rank,capi_rlon_intent,rlon_capi);
  if (capi_rlon_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 2nd argument `rlon' of _stripack.trans to C/Fortran array" );
  } else {
    rlon = (double *)(PyArray_DATA(capi_rlon_tmp));

  /* Processing variable x */
  x_Dims[0]=n;
  capi_x_intent |= F2PY_INTENT_OUT|F2PY_INTENT_HIDE;
  capi_x_tmp = array_from_pyobj(NPY_DOUBLE,x_Dims,x_Rank,capi_x_intent,Py_None);
  if (capi_x_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting hidden `x' of _stripack.trans to C/Fortran array" );
  } else {
    x = (double *)(PyArray_DATA(capi_x_tmp));

  /* Processing variable y */
  y_Dims[0]=n;
  capi_y_intent |= F2PY_INTENT_OUT|F2PY_INTENT_HIDE;
  capi_y_tmp = array_from_pyobj(NPY_DOUBLE,y_Dims,y_Rank,capi_y_intent,Py_None);
  if (capi_y_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting hidden `y' of _stripack.trans to C/Fortran array" );
  } else {
    y = (double *)(PyArray_DATA(capi_y_tmp));

  /* Processing variable z */
  z_Dims[0]=n;
  capi_z_intent |= F2PY_INTENT_OUT|F2PY_INTENT_HIDE;
  capi_z_tmp = array_from_pyobj(NPY_DOUBLE,z_Dims,z_Rank,capi_z_intent,Py_None);
  if (capi_z_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting hidden `z' of _stripack.trans to C/Fortran array" );
  } else {
    z = (double *)(PyArray_DATA(capi_z_tmp));

/*end of frompyobj*/
#ifdef F2PY_REPORT_ATEXIT
f2py_start_call_clock();
#endif
/*callfortranroutine*/
        (*f2py_func)(&n,rlat,rlon,x,y,z);
if (PyErr_Occurred())
  f2py_success = 0;
#ifdef F2PY_REPORT_ATEXIT
f2py_stop_call_clock();
#endif
/*end of callfortranroutine*/
    if (f2py_success) {
/*pyobjfrom*/
/*end of pyobjfrom*/
    CFUNCSMESS("Building return value.\n");
    capi_buildvalue = Py_BuildValue("NNN",capi_x_tmp,capi_y_tmp,capi_z_tmp);
/*closepyobjfrom*/
/*end of closepyobjfrom*/
    } /*if (f2py_success) after callfortranroutine*/
/*cleanupfrompyobj*/
  }  /*if (capi_z_tmp == NULL) ... else of z*/
  /* End of cleaning variable z */
  }  /*if (capi_y_tmp == NULL) ... else of y*/
  /* End of cleaning variable y */
  }  /*if (capi_x_tmp == NULL) ... else of x*/
  /* End of cleaning variable x */
  if((PyObject *)capi_rlon_tmp!=rlon_capi) {
    Py_XDECREF(capi_rlon_tmp); }
  }  /*if (capi_rlon_tmp == NULL) ... else of rlon*/
  /* End of cleaning variable rlon */
  /* End of cleaning variable n */
  if((PyObject *)capi_rlat_tmp!=rlat_capi) {
    Py_XDECREF(capi_rlat_tmp); }
  }  /*if (capi_rlat_tmp == NULL) ... else of rlat*/
  /* End of cleaning variable rlat */
/*end of cleanupfrompyobj*/
  if (capi_buildvalue == NULL) {
/*routdebugfailure*/
  } else {
/*routdebugleave*/
  }
  CFUNCSMESS("Freeing memory.\n");
/*freemem*/
#ifdef F2PY_REPORT_ATEXIT
f2py_stop_clock();
#endif
  return capi_buildvalue;
}
/******************************** end of trans ********************************/

/*********************************** trfind ***********************************/
static char doc_f2py_rout__stripack_trfind[] = "\
b1,b2,b3,i1,i2,i3 = trfind(nst,p,x,y,z,list,lptr,lend)\n\nWrapper for ``trfind``.\
\n\nParameters\n----------\n"
"nst : input int\n"
"p : input rank-1 array('d') with bounds (3)\n"
"x : input rank-1 array('d') with bounds (n)\n"
"y : input rank-1 array('d') with bounds (n)\n"
"z : input rank-1 array('d') with bounds (n)\n"
"list : input rank-1 array('i') with bounds (6 * n - 12)\n"
"lptr : input rank-1 array('i') with bounds (6 * n - 12)\n"
"lend : input rank-1 array('i') with bounds (n)\n"
"\nReturns\n-------\n"
"b1 : float\n"
"b2 : float\n"
"b3 : float\n"
"i1 : int\n"
"i2 : int\n"
"i3 : int";
/* extern void F_FUNC(trfind,TRFIND)(int*,double*,int*,double*,double*,double*,int*,int*,int*,double*,double*,double*,int*,int*,int*); */
static PyObject *f2py_rout__stripack_trfind(const PyObject *capi_self,
                           PyObject *capi_args,
                           PyObject *capi_keywds,
                           void (*f2py_func)(int*,double*,int*,double*,double*,double*,int*,int*,int*,double*,double*,double*,int*,int*,int*)) {
  PyObject * volatile capi_buildvalue = NULL;
  volatile int f2py_success = 1;
/*decl*/

  int nst = 0;
  PyObject *nst_capi = Py_None;
  double *p = NULL;
  npy_intp p_Dims[1] = {-1};
  const int p_Rank = 1;
  PyArrayObject *capi_p_tmp = NULL;
  int capi_p_intent = 0;
  PyObject *p_capi = Py_None;
  int n = 0;
  double *x = NULL;
  npy_intp x_Dims[1] = {-1};
  const int x_Rank = 1;
  PyArrayObject *capi_x_tmp = NULL;
  int capi_x_intent = 0;
  PyObject *x_capi = Py_None;
  double *y = NULL;
  npy_intp y_Dims[1] = {-1};
  const int y_Rank = 1;
  PyArrayObject *capi_y_tmp = NULL;
  int capi_y_intent = 0;
  PyObject *y_capi = Py_None;
  double *z = NULL;
  npy_intp z_Dims[1] = {-1};
  const int z_Rank = 1;
  PyArrayObject *capi_z_tmp = NULL;
  int capi_z_intent = 0;
  PyObject *z_capi = Py_None;
  int *list = NULL;
  npy_intp list_Dims[1] = {-1};
  const int list_Rank = 1;
  PyArrayObject *capi_list_tmp = NULL;
  int capi_list_intent = 0;
  PyObject *list_capi = Py_None;
  int *lptr = NULL;
  npy_intp lptr_Dims[1] = {-1};
  const int lptr_Rank = 1;
  PyArrayObject *capi_lptr_tmp = NULL;
  int capi_lptr_intent = 0;
  PyObject *lptr_capi = Py_None;
  int *lend = NULL;
  npy_intp lend_Dims[1] = {-1};
  const int lend_Rank = 1;
  PyArrayObject *capi_lend_tmp = NULL;
  int capi_lend_intent = 0;
  PyObject *lend_capi = Py_None;
  double b1 = 0;
  double b2 = 0;
  double b3 = 0;
  int i1 = 0;
  int i2 = 0;
  int i3 = 0;
  static char *capi_kwlist[] = {"nst","p","x","y","z","list","lptr","lend",NULL};

/*routdebugenter*/
#ifdef F2PY_REPORT_ATEXIT
f2py_start_clock();
#endif
  if (!PyArg_ParseTupleAndKeywords(capi_args,capi_keywds,\
    "OOOOOOOO:_stripack.trfind",\
    capi_kwlist,&nst_capi,&p_capi,&x_capi,&y_capi,&z_capi,&list_capi,&lptr_capi,&lend_capi))
    return NULL;
/*frompyobj*/
  /* Processing variable nst */
    f2py_success = int_from_pyobj(&nst,nst_capi,"_stripack.trfind() 1st argument (nst) can't be converted to int");
  if (f2py_success) {
  /* Processing variable p */
  p_Dims[0]=3;
  capi_p_intent |= F2PY_INTENT_IN;
  capi_p_tmp = array_from_pyobj(NPY_DOUBLE,p_Dims,p_Rank,capi_p_intent,p_capi);
  if (capi_p_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 2nd argument `p' of _stripack.trfind to C/Fortran array" );
  } else {
    p = (double *)(PyArray_DATA(capi_p_tmp));

  /* Processing variable x */
  ;
  capi_x_intent |= F2PY_INTENT_IN;
  capi_x_tmp = array_from_pyobj(NPY_DOUBLE,x_Dims,x_Rank,capi_x_intent,x_capi);
  if (capi_x_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 3rd argument `x' of _stripack.trfind to C/Fortran array" );
  } else {
    x = (double *)(PyArray_DATA(capi_x_tmp));

  /* Processing variable b1 */
  /* Processing variable b2 */
  /* Processing variable b3 */
  /* Processing variable i1 */
  /* Processing variable i2 */
  /* Processing variable i3 */
  /* Processing variable n */
  n = len(x);
  /* Processing variable y */
  y_Dims[0]=n;
  capi_y_intent |= F2PY_INTENT_IN;
  capi_y_tmp = array_from_pyobj(NPY_DOUBLE,y_Dims,y_Rank,capi_y_intent,y_capi);
  if (capi_y_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 4th argument `y' of _stripack.trfind to C/Fortran array" );
  } else {
    y = (double *)(PyArray_DATA(capi_y_tmp));

  /* Processing variable z */
  z_Dims[0]=n;
  capi_z_intent |= F2PY_INTENT_IN;
  capi_z_tmp = array_from_pyobj(NPY_DOUBLE,z_Dims,z_Rank,capi_z_intent,z_capi);
  if (capi_z_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 5th argument `z' of _stripack.trfind to C/Fortran array" );
  } else {
    z = (double *)(PyArray_DATA(capi_z_tmp));

  /* Processing variable list */
  list_Dims[0]=6 * n - 12;
  capi_list_intent |= F2PY_INTENT_IN;
  capi_list_tmp = array_from_pyobj(NPY_INT,list_Dims,list_Rank,capi_list_intent,list_capi);
  if (capi_list_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 6th argument `list' of _stripack.trfind to C/Fortran array" );
  } else {
    list = (int *)(PyArray_DATA(capi_list_tmp));

  /* Processing variable lptr */
  lptr_Dims[0]=6 * n - 12;
  capi_lptr_intent |= F2PY_INTENT_IN;
  capi_lptr_tmp = array_from_pyobj(NPY_INT,lptr_Dims,lptr_Rank,capi_lptr_intent,lptr_capi);
  if (capi_lptr_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 7th argument `lptr' of _stripack.trfind to C/Fortran array" );
  } else {
    lptr = (int *)(PyArray_DATA(capi_lptr_tmp));

  /* Processing variable lend */
  lend_Dims[0]=n;
  capi_lend_intent |= F2PY_INTENT_IN;
  capi_lend_tmp = array_from_pyobj(NPY_INT,lend_Dims,lend_Rank,capi_lend_intent,lend_capi);
  if (capi_lend_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 8th argument `lend' of _stripack.trfind to C/Fortran array" );
  } else {
    lend = (int *)(PyArray_DATA(capi_lend_tmp));

/*end of frompyobj*/
#ifdef F2PY_REPORT_ATEXIT
f2py_start_call_clock();
#endif
/*callfortranroutine*/
        (*f2py_func)(&nst,p,&n,x,y,z,list,lptr,lend,&b1,&b2,&b3,&i1,&i2,&i3);
if (PyErr_Occurred())
  f2py_success = 0;
#ifdef F2PY_REPORT_ATEXIT
f2py_stop_call_clock();
#endif
/*end of callfortranroutine*/
    if (f2py_success) {
/*pyobjfrom*/
/*end of pyobjfrom*/
    CFUNCSMESS("Building return value.\n");
    capi_buildvalue = Py_BuildValue("dddiii",b1,b2,b3,i1,i2,i3);
/*closepyobjfrom*/
/*end of closepyobjfrom*/
    } /*if (f2py_success) after callfortranroutine*/
/*cleanupfrompyobj*/
  if((PyObject *)capi_lend_tmp!=lend_capi) {
    Py_XDECREF(capi_lend_tmp); }
  }  /*if (capi_lend_tmp == NULL) ... else of lend*/
  /* End of cleaning variable lend */
  if((PyObject *)capi_lptr_tmp!=lptr_capi) {
    Py_XDECREF(capi_lptr_tmp); }
  }  /*if (capi_lptr_tmp == NULL) ... else of lptr*/
  /* End of cleaning variable lptr */
  if((PyObject *)capi_list_tmp!=list_capi) {
    Py_XDECREF(capi_list_tmp); }
  }  /*if (capi_list_tmp == NULL) ... else of list*/
  /* End of cleaning variable list */
  if((PyObject *)capi_z_tmp!=z_capi) {
    Py_XDECREF(capi_z_tmp); }
  }  /*if (capi_z_tmp == NULL) ... else of z*/
  /* End of cleaning variable z */
  if((PyObject *)capi_y_tmp!=y_capi) {
    Py_XDECREF(capi_y_tmp); }
  }  /*if (capi_y_tmp == NULL) ... else of y*/
  /* End of cleaning variable y */
  /* End of cleaning variable n */
  /* End of cleaning variable i3 */
  /* End of cleaning variable i2 */
  /* End of cleaning variable i1 */
  /* End of cleaning variable b3 */
  /* End of cleaning variable b2 */
  /* End of cleaning variable b1 */
  if((PyObject *)capi_x_tmp!=x_capi) {
    Py_XDECREF(capi_x_tmp); }
  }  /*if (capi_x_tmp == NULL) ... else of x*/
  /* End of cleaning variable x */
  if((PyObject *)capi_p_tmp!=p_capi) {
    Py_XDECREF(capi_p_tmp); }
  }  /*if (capi_p_tmp == NULL) ... else of p*/
  /* End of cleaning variable p */
  } /*if (f2py_success) of nst*/
  /* End of cleaning variable nst */
/*end of cleanupfrompyobj*/
  if (capi_buildvalue == NULL) {
/*routdebugfailure*/
  } else {
/*routdebugleave*/
  }
  CFUNCSMESS("Freeing memory.\n");
/*freemem*/
#ifdef F2PY_REPORT_ATEXIT
f2py_stop_clock();
#endif
  return capi_buildvalue;
}
/******************************* end of trfind *******************************/

/*********************************** trmesh ***********************************/
static char doc_f2py_rout__stripack_trmesh[] = "\
list,lptr,lend,ier = trmesh(x,y,z)\n\nWrapper for ``trmesh``.\
\n\nParameters\n----------\n"
"x : input rank-1 array('d') with bounds (n)\n"
"y : input rank-1 array('d') with bounds (n)\n"
"z : input rank-1 array('d') with bounds (n)\n"
"\nReturns\n-------\n"
"list : rank-1 array('i') with bounds (6 * n - 12)\n"
"lptr : rank-1 array('i') with bounds (6 * n - 12)\n"
"lend : rank-1 array('i') with bounds (n)\n"
"ier : int";
/* extern void F_FUNC(trmesh,TRMESH)(int*,double*,double*,double*,int*,int*,int*,int*); */
static PyObject *f2py_rout__stripack_trmesh(const PyObject *capi_self,
                           PyObject *capi_args,
                           PyObject *capi_keywds,
                           void (*f2py_func)(int*,double*,double*,double*,int*,int*,int*,int*)) {
  PyObject * volatile capi_buildvalue = NULL;
  volatile int f2py_success = 1;
/*decl*/

  int n = 0;
  double *x = NULL;
  npy_intp x_Dims[1] = {-1};
  const int x_Rank = 1;
  PyArrayObject *capi_x_tmp = NULL;
  int capi_x_intent = 0;
  PyObject *x_capi = Py_None;
  double *y = NULL;
  npy_intp y_Dims[1] = {-1};
  const int y_Rank = 1;
  PyArrayObject *capi_y_tmp = NULL;
  int capi_y_intent = 0;
  PyObject *y_capi = Py_None;
  double *z = NULL;
  npy_intp z_Dims[1] = {-1};
  const int z_Rank = 1;
  PyArrayObject *capi_z_tmp = NULL;
  int capi_z_intent = 0;
  PyObject *z_capi = Py_None;
  int *list = NULL;
  npy_intp list_Dims[1] = {-1};
  const int list_Rank = 1;
  PyArrayObject *capi_list_tmp = NULL;
  int capi_list_intent = 0;
  int *lptr = NULL;
  npy_intp lptr_Dims[1] = {-1};
  const int lptr_Rank = 1;
  PyArrayObject *capi_lptr_tmp = NULL;
  int capi_lptr_intent = 0;
  int *lend = NULL;
  npy_intp lend_Dims[1] = {-1};
  const int lend_Rank = 1;
  PyArrayObject *capi_lend_tmp = NULL;
  int capi_lend_intent = 0;
  int ier = 0;
  static char *capi_kwlist[] = {"x","y","z",NULL};

/*routdebugenter*/
#ifdef F2PY_REPORT_ATEXIT
f2py_start_clock();
#endif
  if (!PyArg_ParseTupleAndKeywords(capi_args,capi_keywds,\
    "OOO:_stripack.trmesh",\
    capi_kwlist,&x_capi,&y_capi,&z_capi))
    return NULL;
/*frompyobj*/
  /* Processing variable x */
  ;
  capi_x_intent |= F2PY_INTENT_IN;
  capi_x_tmp = array_from_pyobj(NPY_DOUBLE,x_Dims,x_Rank,capi_x_intent,x_capi);
  if (capi_x_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 1st argument `x' of _stripack.trmesh to C/Fortran array" );
  } else {
    x = (double *)(PyArray_DATA(capi_x_tmp));

  /* Processing variable ier */
  /* Processing variable n */
  n = len(x);
  /* Processing variable y */
  y_Dims[0]=n;
  capi_y_intent |= F2PY_INTENT_IN;
  capi_y_tmp = array_from_pyobj(NPY_DOUBLE,y_Dims,y_Rank,capi_y_intent,y_capi);
  if (capi_y_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 2nd argument `y' of _stripack.trmesh to C/Fortran array" );
  } else {
    y = (double *)(PyArray_DATA(capi_y_tmp));

  /* Processing variable z */
  z_Dims[0]=n;
  capi_z_intent |= F2PY_INTENT_IN;
  capi_z_tmp = array_from_pyobj(NPY_DOUBLE,z_Dims,z_Rank,capi_z_intent,z_capi);
  if (capi_z_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 3rd argument `z' of _stripack.trmesh to C/Fortran array" );
  } else {
    z = (double *)(PyArray_DATA(capi_z_tmp));

  /* Processing variable list */
  list_Dims[0]=6 * n - 12;
  capi_list_intent |= F2PY_INTENT_OUT|F2PY_INTENT_HIDE;
  capi_list_tmp = array_from_pyobj(NPY_INT,list_Dims,list_Rank,capi_list_intent,Py_None);
  if (capi_list_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting hidden `list' of _stripack.trmesh to C/Fortran array" );
  } else {
    list = (int *)(PyArray_DATA(capi_list_tmp));

  /* Processing variable lptr */
  lptr_Dims[0]=6 * n - 12;
  capi_lptr_intent |= F2PY_INTENT_OUT|F2PY_INTENT_HIDE;
  capi_lptr_tmp = array_from_pyobj(NPY_INT,lptr_Dims,lptr_Rank,capi_lptr_intent,Py_None);
  if (capi_lptr_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting hidden `lptr' of _stripack.trmesh to C/Fortran array" );
  } else {
    lptr = (int *)(PyArray_DATA(capi_lptr_tmp));

  /* Processing variable lend */
  lend_Dims[0]=n;
  capi_lend_intent |= F2PY_INTENT_OUT|F2PY_INTENT_HIDE;
  capi_lend_tmp = array_from_pyobj(NPY_INT,lend_Dims,lend_Rank,capi_lend_intent,Py_None);
  if (capi_lend_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting hidden `lend' of _stripack.trmesh to C/Fortran array" );
  } else {
    lend = (int *)(PyArray_DATA(capi_lend_tmp));

/*end of frompyobj*/
#ifdef F2PY_REPORT_ATEXIT
f2py_start_call_clock();
#endif
/*callfortranroutine*/
        (*f2py_func)(&n,x,y,z,list,lptr,lend,&ier);
if (PyErr_Occurred())
  f2py_success = 0;
#ifdef F2PY_REPORT_ATEXIT
f2py_stop_call_clock();
#endif
/*end of callfortranroutine*/
    if (f2py_success) {
/*pyobjfrom*/
/*end of pyobjfrom*/
    CFUNCSMESS("Building return value.\n");
    capi_buildvalue = Py_BuildValue("NNNi",capi_list_tmp,capi_lptr_tmp,capi_lend_tmp,ier);
/*closepyobjfrom*/
/*end of closepyobjfrom*/
    } /*if (f2py_success) after callfortranroutine*/
/*cleanupfrompyobj*/
  }  /*if (capi_lend_tmp == NULL) ... else of lend*/
  /* End of cleaning variable lend */
  }  /*if (capi_lptr_tmp == NULL) ... else of lptr*/
  /* End of cleaning variable lptr */
  }  /*if (capi_list_tmp == NULL) ... else of list*/
  /* End of cleaning variable list */
  if((PyObject *)capi_z_tmp!=z_capi) {
    Py_XDECREF(capi_z_tmp); }
  }  /*if (capi_z_tmp == NULL) ... else of z*/
  /* End of cleaning variable z */
  if((PyObject *)capi_y_tmp!=y_capi) {
    Py_XDECREF(capi_y_tmp); }
  }  /*if (capi_y_tmp == NULL) ... else of y*/
  /* End of cleaning variable y */
  /* End of cleaning variable n */
  /* End of cleaning variable ier */
  if((PyObject *)capi_x_tmp!=x_capi) {
    Py_XDECREF(capi_x_tmp); }
  }  /*if (capi_x_tmp == NULL) ... else of x*/
  /* End of cleaning variable x */
/*end of cleanupfrompyobj*/
  if (capi_buildvalue == NULL) {
/*routdebugfailure*/
  } else {
/*routdebugleave*/
  }
  CFUNCSMESS("Freeing memory.\n");
/*freemem*/
#ifdef F2PY_REPORT_ATEXIT
f2py_stop_clock();
#endif
  return capi_buildvalue;
}
/******************************* end of trmesh *******************************/

/*********************************** interp ***********************************/
static char doc_f2py_rout__stripack_interp[] = "\
interp(order,plat,plon,x,y,z,w,list,lptr,lend,ist,pw,ier,[n])\n\nWrapper for ``interp``.\
\n\nParameters\n----------\n"
"order : input int\n"
"plat : input float\n"
"plon : input float\n"
"x : input rank-1 array('d') with bounds (n)\n"
"y : input rank-1 array('d') with bounds (n)\n"
"z : input rank-1 array('d') with bounds (n)\n"
"w : input rank-1 array('d') with bounds (n)\n"
"list : input rank-1 array('i') with bounds (6 * n - 12)\n"
"lptr : input rank-1 array('i') with bounds (6 * n - 12)\n"
"lend : input rank-1 array('i') with bounds (n)\n"
"ist : input int\n"
"pw : input float\n"
"ier : input int\n"
"\nOther Parameters\n----------------\n"
"n : input int, optional\n    Default: len(x)";
/* extern void F_FUNC(interp,INTERP)(int*,int*,double*,double*,double*,double*,double*,double*,int*,int*,int*,int*,double*,int*); */
static PyObject *f2py_rout__stripack_interp(const PyObject *capi_self,
                           PyObject *capi_args,
                           PyObject *capi_keywds,
                           void (*f2py_func)(int*,int*,double*,double*,double*,double*,double*,double*,int*,int*,int*,int*,double*,int*)) {
  PyObject * volatile capi_buildvalue = NULL;
  volatile int f2py_success = 1;
/*decl*/

  int n = 0;
  PyObject *n_capi = Py_None;
  int order = 0;
  PyObject *order_capi = Py_None;
  double plat = 0;
  PyObject *plat_capi = Py_None;
  double plon = 0;
  PyObject *plon_capi = Py_None;
  double *x = NULL;
  npy_intp x_Dims[1] = {-1};
  const int x_Rank = 1;
  PyArrayObject *capi_x_tmp = NULL;
  int capi_x_intent = 0;
  PyObject *x_capi = Py_None;
  double *y = NULL;
  npy_intp y_Dims[1] = {-1};
  const int y_Rank = 1;
  PyArrayObject *capi_y_tmp = NULL;
  int capi_y_intent = 0;
  PyObject *y_capi = Py_None;
  double *z = NULL;
  npy_intp z_Dims[1] = {-1};
  const int z_Rank = 1;
  PyArrayObject *capi_z_tmp = NULL;
  int capi_z_intent = 0;
  PyObject *z_capi = Py_None;
  double *w = NULL;
  npy_intp w_Dims[1] = {-1};
  const int w_Rank = 1;
  PyArrayObject *capi_w_tmp = NULL;
  int capi_w_intent = 0;
  PyObject *w_capi = Py_None;
  int *list = NULL;
  npy_intp list_Dims[1] = {-1};
  const int list_Rank = 1;
  PyArrayObject *capi_list_tmp = NULL;
  int capi_list_intent = 0;
  PyObject *list_capi = Py_None;
  int *lptr = NULL;
  npy_intp lptr_Dims[1] = {-1};
  const int lptr_Rank = 1;
  PyArrayObject *capi_lptr_tmp = NULL;
  int capi_lptr_intent = 0;
  PyObject *lptr_capi = Py_None;
  int *lend = NULL;
  npy_intp lend_Dims[1] = {-1};
  const int lend_Rank = 1;
  PyArrayObject *capi_lend_tmp = NULL;
  int capi_lend_intent = 0;
  PyObject *lend_capi = Py_None;
  int ist = 0;
  PyObject *ist_capi = Py_None;
  double pw = 0;
  PyObject *pw_capi = Py_None;
  int ier = 0;
  PyObject *ier_capi = Py_None;
  static char *capi_kwlist[] = {"order","plat","plon","x","y","z","w","list","lptr","lend","ist","pw","ier","n",NULL};

/*routdebugenter*/
#ifdef F2PY_REPORT_ATEXIT
f2py_start_clock();
#endif
  if (!PyArg_ParseTupleAndKeywords(capi_args,capi_keywds,\
    "OOOOOOOOOOOOO|O:_stripack.interp",\
    capi_kwlist,&order_capi,&plat_capi,&plon_capi,&x_capi,&y_capi,&z_capi,&w_capi,&list_capi,&lptr_capi,&lend_capi,&ist_capi,&pw_capi,&ier_capi,&n_capi))
    return NULL;
/*frompyobj*/
  /* Processing variable order */
    f2py_success = int_from_pyobj(&order,order_capi,"_stripack.interp() 1st argument (order) can't be converted to int");
  if (f2py_success) {
  /* Processing variable plat */
    f2py_success = double_from_pyobj(&plat,plat_capi,"_stripack.interp() 2nd argument (plat) can't be converted to double");
  if (f2py_success) {
  /* Processing variable plon */
    f2py_success = double_from_pyobj(&plon,plon_capi,"_stripack.interp() 3rd argument (plon) can't be converted to double");
  if (f2py_success) {
  /* Processing variable x */
  ;
  capi_x_intent |= F2PY_INTENT_IN;
  capi_x_tmp = array_from_pyobj(NPY_DOUBLE,x_Dims,x_Rank,capi_x_intent,x_capi);
  if (capi_x_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 4th argument `x' of _stripack.interp to C/Fortran array" );
  } else {
    x = (double *)(PyArray_DATA(capi_x_tmp));

  /* Processing variable ist */
    f2py_success = int_from_pyobj(&ist,ist_capi,"_stripack.interp() 11st argument (ist) can't be converted to int");
  if (f2py_success) {
  /* Processing variable pw */
    f2py_success = double_from_pyobj(&pw,pw_capi,"_stripack.interp() 12nd argument (pw) can't be converted to double");
  if (f2py_success) {
  /* Processing variable ier */
    f2py_success = int_from_pyobj(&ier,ier_capi,"_stripack.interp() 13rd argument (ier) can't be converted to int");
  if (f2py_success) {
  /* Processing variable n */
  if (n_capi == Py_None) n = len(x); else
    f2py_success = int_from_pyobj(&n,n_capi,"_stripack.interp() 1st keyword (n) can't be converted to int");
  if (f2py_success) {
  CHECKSCALAR(len(x)>=n,"len(x)>=n","1st keyword n","interp:n=%d",n) {
  /* Processing variable y */
  y_Dims[0]=n;
  capi_y_intent |= F2PY_INTENT_IN;
  capi_y_tmp = array_from_pyobj(NPY_DOUBLE,y_Dims,y_Rank,capi_y_intent,y_capi);
  if (capi_y_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 5th argument `y' of _stripack.interp to C/Fortran array" );
  } else {
    y = (double *)(PyArray_DATA(capi_y_tmp));

  /* Processing variable z */
  z_Dims[0]=n;
  capi_z_intent |= F2PY_INTENT_IN;
  capi_z_tmp = array_from_pyobj(NPY_DOUBLE,z_Dims,z_Rank,capi_z_intent,z_capi);
  if (capi_z_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 6th argument `z' of _stripack.interp to C/Fortran array" );
  } else {
    z = (double *)(PyArray_DATA(capi_z_tmp));

  /* Processing variable w */
  w_Dims[0]=n;
  capi_w_intent |= F2PY_INTENT_IN;
  capi_w_tmp = array_from_pyobj(NPY_DOUBLE,w_Dims,w_Rank,capi_w_intent,w_capi);
  if (capi_w_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 7th argument `w' of _stripack.interp to C/Fortran array" );
  } else {
    w = (double *)(PyArray_DATA(capi_w_tmp));

  /* Processing variable list */
  list_Dims[0]=6 * n - 12;
  capi_list_intent |= F2PY_INTENT_IN;
  capi_list_tmp = array_from_pyobj(NPY_INT,list_Dims,list_Rank,capi_list_intent,list_capi);
  if (capi_list_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 8th argument `list' of _stripack.interp to C/Fortran array" );
  } else {
    list = (int *)(PyArray_DATA(capi_list_tmp));

  /* Processing variable lptr */
  lptr_Dims[0]=6 * n - 12;
  capi_lptr_intent |= F2PY_INTENT_IN;
  capi_lptr_tmp = array_from_pyobj(NPY_INT,lptr_Dims,lptr_Rank,capi_lptr_intent,lptr_capi);
  if (capi_lptr_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 9th argument `lptr' of _stripack.interp to C/Fortran array" );
  } else {
    lptr = (int *)(PyArray_DATA(capi_lptr_tmp));

  /* Processing variable lend */
  lend_Dims[0]=n;
  capi_lend_intent |= F2PY_INTENT_IN;
  capi_lend_tmp = array_from_pyobj(NPY_INT,lend_Dims,lend_Rank,capi_lend_intent,lend_capi);
  if (capi_lend_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 10th argument `lend' of _stripack.interp to C/Fortran array" );
  } else {
    lend = (int *)(PyArray_DATA(capi_lend_tmp));

/*end of frompyobj*/
#ifdef F2PY_REPORT_ATEXIT
f2py_start_call_clock();
#endif
/*callfortranroutine*/
        (*f2py_func)(&n,&order,&plat,&plon,x,y,z,w,list,lptr,lend,&ist,&pw,&ier);
if (PyErr_Occurred())
  f2py_success = 0;
#ifdef F2PY_REPORT_ATEXIT
f2py_stop_call_clock();
#endif
/*end of callfortranroutine*/
    if (f2py_success) {
/*pyobjfrom*/
/*end of pyobjfrom*/
    CFUNCSMESS("Building return value.\n");
    capi_buildvalue = Py_BuildValue("");
/*closepyobjfrom*/
/*end of closepyobjfrom*/
    } /*if (f2py_success) after callfortranroutine*/
/*cleanupfrompyobj*/
  if((PyObject *)capi_lend_tmp!=lend_capi) {
    Py_XDECREF(capi_lend_tmp); }
  }  /*if (capi_lend_tmp == NULL) ... else of lend*/
  /* End of cleaning variable lend */
  if((PyObject *)capi_lptr_tmp!=lptr_capi) {
    Py_XDECREF(capi_lptr_tmp); }
  }  /*if (capi_lptr_tmp == NULL) ... else of lptr*/
  /* End of cleaning variable lptr */
  if((PyObject *)capi_list_tmp!=list_capi) {
    Py_XDECREF(capi_list_tmp); }
  }  /*if (capi_list_tmp == NULL) ... else of list*/
  /* End of cleaning variable list */
  if((PyObject *)capi_w_tmp!=w_capi) {
    Py_XDECREF(capi_w_tmp); }
  }  /*if (capi_w_tmp == NULL) ... else of w*/
  /* End of cleaning variable w */
  if((PyObject *)capi_z_tmp!=z_capi) {
    Py_XDECREF(capi_z_tmp); }
  }  /*if (capi_z_tmp == NULL) ... else of z*/
  /* End of cleaning variable z */
  if((PyObject *)capi_y_tmp!=y_capi) {
    Py_XDECREF(capi_y_tmp); }
  }  /*if (capi_y_tmp == NULL) ... else of y*/
  /* End of cleaning variable y */
  } /*CHECKSCALAR(len(x)>=n)*/
  } /*if (f2py_success) of n*/
  /* End of cleaning variable n */
  } /*if (f2py_success) of ier*/
  /* End of cleaning variable ier */
  } /*if (f2py_success) of pw*/
  /* End of cleaning variable pw */
  } /*if (f2py_success) of ist*/
  /* End of cleaning variable ist */
  if((PyObject *)capi_x_tmp!=x_capi) {
    Py_XDECREF(capi_x_tmp); }
  }  /*if (capi_x_tmp == NULL) ... else of x*/
  /* End of cleaning variable x */
  } /*if (f2py_success) of plon*/
  /* End of cleaning variable plon */
  } /*if (f2py_success) of plat*/
  /* End of cleaning variable plat */
  } /*if (f2py_success) of order*/
  /* End of cleaning variable order */
/*end of cleanupfrompyobj*/
  if (capi_buildvalue == NULL) {
/*routdebugfailure*/
  } else {
/*routdebugleave*/
  }
  CFUNCSMESS("Freeing memory.\n");
/*freemem*/
#ifdef F2PY_REPORT_ATEXIT
f2py_stop_clock();
#endif
  return capi_buildvalue;
}
/******************************* end of interp *******************************/

/*********************************** getnp ***********************************/
static char doc_f2py_rout__stripack_getnp[] = "\
list,lend,npts,df,ier = getnp(x,y,z,list,lptr,npts,[l])\n\nWrapper for ``getnp``.\
\n\nParameters\n----------\n"
"x : input rank-1 array('d') with bounds (*)\n"
"y : input rank-1 array('d') with bounds (*)\n"
"z : input rank-1 array('d') with bounds (*)\n"
"list : input rank-1 array('i') with bounds (*)\n"
"lptr : input rank-1 array('i') with bounds (*)\n"
"npts : input rank-1 array('i') with bounds (l)\n"
"\nOther Parameters\n----------------\n"
"l : input int, optional\n    Default: len(npts)\n"
"\nReturns\n-------\n"
"list : rank-1 array('i') with bounds (*)\n"
"lend : rank-1 array('i') with bounds (*)\n"
"npts : rank-1 array('i') with bounds (l)\n"
"df : float\n"
"ier : int";
/* extern void F_FUNC(getnp,GETNP)(double*,double*,double*,int*,int*,int*,int*,int*,double*,int*); */
static PyObject *f2py_rout__stripack_getnp(const PyObject *capi_self,
                           PyObject *capi_args,
                           PyObject *capi_keywds,
                           void (*f2py_func)(double*,double*,double*,int*,int*,int*,int*,int*,double*,int*)) {
  PyObject * volatile capi_buildvalue = NULL;
  volatile int f2py_success = 1;
/*decl*/

  double *x = NULL;
  npy_intp x_Dims[1] = {-1};
  const int x_Rank = 1;
  PyArrayObject *capi_x_tmp = NULL;
  int capi_x_intent = 0;
  PyObject *x_capi = Py_None;
  double *y = NULL;
  npy_intp y_Dims[1] = {-1};
  const int y_Rank = 1;
  PyArrayObject *capi_y_tmp = NULL;
  int capi_y_intent = 0;
  PyObject *y_capi = Py_None;
  double *z = NULL;
  npy_intp z_Dims[1] = {-1};
  const int z_Rank = 1;
  PyArrayObject *capi_z_tmp = NULL;
  int capi_z_intent = 0;
  PyObject *z_capi = Py_None;
  int *list = NULL;
  npy_intp list_Dims[1] = {-1};
  const int list_Rank = 1;
  PyArrayObject *capi_list_tmp = NULL;
  int capi_list_intent = 0;
  PyObject *list_capi = Py_None;
  int *lptr = NULL;
  npy_intp lptr_Dims[1] = {-1};
  const int lptr_Rank = 1;
  PyArrayObject *capi_lptr_tmp = NULL;
  int capi_lptr_intent = 0;
  PyObject *lptr_capi = Py_None;
  int *lend = NULL;
  npy_intp lend_Dims[1] = {-1};
  const int lend_Rank = 1;
  PyArrayObject *capi_lend_tmp = NULL;
  int capi_lend_intent = 0;
  int l = 0;
  PyObject *l_capi = Py_None;
  int *npts = NULL;
  npy_intp npts_Dims[1] = {-1};
  const int npts_Rank = 1;
  PyArrayObject *capi_npts_tmp = NULL;
  int capi_npts_intent = 0;
  PyObject *npts_capi = Py_None;
  double df = 0;
  int ier = 0;
  static char *capi_kwlist[] = {"x","y","z","list","lptr","npts","l",NULL};

/*routdebugenter*/
#ifdef F2PY_REPORT_ATEXIT
f2py_start_clock();
#endif
  if (!PyArg_ParseTupleAndKeywords(capi_args,capi_keywds,\
    "OOOOOO|O:_stripack.getnp",\
    capi_kwlist,&x_capi,&y_capi,&z_capi,&list_capi,&lptr_capi,&npts_capi,&l_capi))
    return NULL;
/*frompyobj*/
  /* Processing variable x */
  ;
  capi_x_intent |= F2PY_INTENT_IN;
  capi_x_tmp = array_from_pyobj(NPY_DOUBLE,x_Dims,x_Rank,capi_x_intent,x_capi);
  if (capi_x_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 1st argument `x' of _stripack.getnp to C/Fortran array" );
  } else {
    x = (double *)(PyArray_DATA(capi_x_tmp));

  /* Processing variable y */
  ;
  capi_y_intent |= F2PY_INTENT_IN;
  capi_y_tmp = array_from_pyobj(NPY_DOUBLE,y_Dims,y_Rank,capi_y_intent,y_capi);
  if (capi_y_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 2nd argument `y' of _stripack.getnp to C/Fortran array" );
  } else {
    y = (double *)(PyArray_DATA(capi_y_tmp));

  /* Processing variable z */
  ;
  capi_z_intent |= F2PY_INTENT_IN;
  capi_z_tmp = array_from_pyobj(NPY_DOUBLE,z_Dims,z_Rank,capi_z_intent,z_capi);
  if (capi_z_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 3rd argument `z' of _stripack.getnp to C/Fortran array" );
  } else {
    z = (double *)(PyArray_DATA(capi_z_tmp));

  /* Processing variable list */
  ;
  capi_list_intent |= F2PY_INTENT_IN|F2PY_INTENT_OUT;
  capi_list_tmp = array_from_pyobj(NPY_INT,list_Dims,list_Rank,capi_list_intent,list_capi);
  if (capi_list_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 4th argument `list' of _stripack.getnp to C/Fortran array" );
  } else {
    list = (int *)(PyArray_DATA(capi_list_tmp));

  /* Processing variable lptr */
  ;
  capi_lptr_intent |= F2PY_INTENT_IN;
  capi_lptr_tmp = array_from_pyobj(NPY_INT,lptr_Dims,lptr_Rank,capi_lptr_intent,lptr_capi);
  if (capi_lptr_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 5th argument `lptr' of _stripack.getnp to C/Fortran array" );
  } else {
    lptr = (int *)(PyArray_DATA(capi_lptr_tmp));

  /* Processing variable lend */
  ;
  capi_lend_intent |= F2PY_INTENT_OUT|F2PY_INTENT_HIDE;
  capi_lend_tmp = array_from_pyobj(NPY_INT,lend_Dims,lend_Rank,capi_lend_intent,Py_None);
  if (capi_lend_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting hidden `lend' of _stripack.getnp to C/Fortran array" );
  } else {
    lend = (int *)(PyArray_DATA(capi_lend_tmp));

  /* Processing variable npts */
  ;
  capi_npts_intent |= F2PY_INTENT_IN|F2PY_INTENT_OUT;
  capi_npts_tmp = array_from_pyobj(NPY_INT,npts_Dims,npts_Rank,capi_npts_intent,npts_capi);
  if (capi_npts_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 6th argument `npts' of _stripack.getnp to C/Fortran array" );
  } else {
    npts = (int *)(PyArray_DATA(capi_npts_tmp));

  /* Processing variable df */
  /* Processing variable ier */
  /* Processing variable l */
  if (l_capi == Py_None) l = len(npts); else
    f2py_success = int_from_pyobj(&l,l_capi,"_stripack.getnp() 1st keyword (l) can't be converted to int");
  if (f2py_success) {
  CHECKSCALAR(len(npts)>=l,"len(npts)>=l","1st keyword l","getnp:l=%d",l) {
/*end of frompyobj*/
#ifdef F2PY_REPORT_ATEXIT
f2py_start_call_clock();
#endif
/*callfortranroutine*/
        (*f2py_func)(x,y,z,list,lptr,lend,&l,npts,&df,&ier);
if (PyErr_Occurred())
  f2py_success = 0;
#ifdef F2PY_REPORT_ATEXIT
f2py_stop_call_clock();
#endif
/*end of callfortranroutine*/
    if (f2py_success) {
/*pyobjfrom*/
/*end of pyobjfrom*/
    CFUNCSMESS("Building return value.\n");
    capi_buildvalue = Py_BuildValue("NNNdi",capi_list_tmp,capi_lend_tmp,capi_npts_tmp,df,ier);
/*closepyobjfrom*/
/*end of closepyobjfrom*/
    } /*if (f2py_success) after callfortranroutine*/
/*cleanupfrompyobj*/
  } /*CHECKSCALAR(len(npts)>=l)*/
  } /*if (f2py_success) of l*/
  /* End of cleaning variable l */
  /* End of cleaning variable ier */
  /* End of cleaning variable df */
  }  /*if (capi_npts_tmp == NULL) ... else of npts*/
  /* End of cleaning variable npts */
  }  /*if (capi_lend_tmp == NULL) ... else of lend*/
  /* End of cleaning variable lend */
  if((PyObject *)capi_lptr_tmp!=lptr_capi) {
    Py_XDECREF(capi_lptr_tmp); }
  }  /*if (capi_lptr_tmp == NULL) ... else of lptr*/
  /* End of cleaning variable lptr */
  }  /*if (capi_list_tmp == NULL) ... else of list*/
  /* End of cleaning variable list */
  if((PyObject *)capi_z_tmp!=z_capi) {
    Py_XDECREF(capi_z_tmp); }
  }  /*if (capi_z_tmp == NULL) ... else of z*/
  /* End of cleaning variable z */
  if((PyObject *)capi_y_tmp!=y_capi) {
    Py_XDECREF(capi_y_tmp); }
  }  /*if (capi_y_tmp == NULL) ... else of y*/
  /* End of cleaning variable y */
  if((PyObject *)capi_x_tmp!=x_capi) {
    Py_XDECREF(capi_x_tmp); }
  }  /*if (capi_x_tmp == NULL) ... else of x*/
  /* End of cleaning variable x */
/*end of cleanupfrompyobj*/
  if (capi_buildvalue == NULL) {
/*routdebugfailure*/
  } else {
/*routdebugleave*/
  }
  CFUNCSMESS("Freeing memory.\n");
/*freemem*/
#ifdef F2PY_REPORT_ATEXIT
f2py_stop_clock();
#endif
  return capi_buildvalue;
}
/******************************** end of getnp ********************************/

/********************************** interp_n **********************************/
static char doc_f2py_rout__stripack_interp_n[] = "\
odata,edata,ierr = interp_n(order,olats,olons,x,y,z,data,lst,lptr,lend)\n\nWrapper for ``interp_n``.\
\n\nParameters\n----------\n"
"order : input int\n"
"olats : input rank-1 array('d') with bounds (nptso)\n"
"olons : input rank-1 array('d') with bounds (nptso)\n"
"x : input rank-1 array('d') with bounds (npts)\n"
"y : input rank-1 array('d') with bounds (npts)\n"
"z : input rank-1 array('d') with bounds (npts)\n"
"data : input rank-1 array('d') with bounds (npts)\n"
"lst : input rank-1 array('i') with bounds (6 * npts - 12)\n"
"lptr : input rank-1 array('i') with bounds (6 * npts - 12)\n"
"lend : input rank-1 array('i') with bounds (npts)\n"
"\nReturns\n-------\n"
"odata : rank-1 array('d') with bounds (nptso)\n"
"edata : rank-1 array('i') with bounds (nptso)\n"
"ierr : int";
/* extern void F_FUNC_US(interp_n,INTERP_N)(int*,int*,int*,double*,double*,double*,double*,double*,double*,int*,int*,int*,double*,int*,int*); */
static PyObject *f2py_rout__stripack_interp_n(const PyObject *capi_self,
                           PyObject *capi_args,
                           PyObject *capi_keywds,
                           void (*f2py_func)(int*,int*,int*,double*,double*,double*,double*,double*,double*,int*,int*,int*,double*,int*,int*)) {
  PyObject * volatile capi_buildvalue = NULL;
  volatile int f2py_success = 1;
/*decl*/

  int npts = 0;
  int nptso = 0;
  int order = 0;
  PyObject *order_capi = Py_None;
  double *olats = NULL;
  npy_intp olats_Dims[1] = {-1};
  const int olats_Rank = 1;
  PyArrayObject *capi_olats_tmp = NULL;
  int capi_olats_intent = 0;
  PyObject *olats_capi = Py_None;
  double *olons = NULL;
  npy_intp olons_Dims[1] = {-1};
  const int olons_Rank = 1;
  PyArrayObject *capi_olons_tmp = NULL;
  int capi_olons_intent = 0;
  PyObject *olons_capi = Py_None;
  double *x = NULL;
  npy_intp x_Dims[1] = {-1};
  const int x_Rank = 1;
  PyArrayObject *capi_x_tmp = NULL;
  int capi_x_intent = 0;
  PyObject *x_capi = Py_None;
  double *y = NULL;
  npy_intp y_Dims[1] = {-1};
  const int y_Rank = 1;
  PyArrayObject *capi_y_tmp = NULL;
  int capi_y_intent = 0;
  PyObject *y_capi = Py_None;
  double *z = NULL;
  npy_intp z_Dims[1] = {-1};
  const int z_Rank = 1;
  PyArrayObject *capi_z_tmp = NULL;
  int capi_z_intent = 0;
  PyObject *z_capi = Py_None;
  double *data = NULL;
  npy_intp data_Dims[1] = {-1};
  const int data_Rank = 1;
  PyArrayObject *capi_data_tmp = NULL;
  int capi_data_intent = 0;
  PyObject *data_capi = Py_None;
  int *lst = NULL;
  npy_intp lst_Dims[1] = {-1};
  const int lst_Rank = 1;
  PyArrayObject *capi_lst_tmp = NULL;
  int capi_lst_intent = 0;
  PyObject *lst_capi = Py_None;
  int *lptr = NULL;
  npy_intp lptr_Dims[1] = {-1};
  const int lptr_Rank = 1;
  PyArrayObject *capi_lptr_tmp = NULL;
  int capi_lptr_intent = 0;
  PyObject *lptr_capi = Py_None;
  int *lend = NULL;
  npy_intp lend_Dims[1] = {-1};
  const int lend_Rank = 1;
  PyArrayObject *capi_lend_tmp = NULL;
  int capi_lend_intent = 0;
  PyObject *lend_capi = Py_None;
  double *odata = NULL;
  npy_intp odata_Dims[1] = {-1};
  const int odata_Rank = 1;
  PyArrayObject *capi_odata_tmp = NULL;
  int capi_odata_intent = 0;
  int *edata = NULL;
  npy_intp edata_Dims[1] = {-1};
  const int edata_Rank = 1;
  PyArrayObject *capi_edata_tmp = NULL;
  int capi_edata_intent = 0;
  int ierr = 0;
  static char *capi_kwlist[] = {"order","olats","olons","x","y","z","data","lst","lptr","lend",NULL};

/*routdebugenter*/
#ifdef F2PY_REPORT_ATEXIT
f2py_start_clock();
#endif
  if (!PyArg_ParseTupleAndKeywords(capi_args,capi_keywds,\
    "OOOOOOOOOO:_stripack.interp_n",\
    capi_kwlist,&order_capi,&olats_capi,&olons_capi,&x_capi,&y_capi,&z_capi,&data_capi,&lst_capi,&lptr_capi,&lend_capi))
    return NULL;
/*frompyobj*/
  /* Processing variable order */
    f2py_success = int_from_pyobj(&order,order_capi,"_stripack.interp_n() 1st argument (order) can't be converted to int");
  if (f2py_success) {
  /* Processing variable ierr */
  /* Processing variable olats */
  ;
  capi_olats_intent |= F2PY_INTENT_IN;
  capi_olats_tmp = array_from_pyobj(NPY_DOUBLE,olats_Dims,olats_Rank,capi_olats_intent,olats_capi);
  if (capi_olats_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 2nd argument `olats' of _stripack.interp_n to C/Fortran array" );
  } else {
    olats = (double *)(PyArray_DATA(capi_olats_tmp));

  /* Processing variable x */
  ;
  capi_x_intent |= F2PY_INTENT_IN;
  capi_x_tmp = array_from_pyobj(NPY_DOUBLE,x_Dims,x_Rank,capi_x_intent,x_capi);
  if (capi_x_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 4th argument `x' of _stripack.interp_n to C/Fortran array" );
  } else {
    x = (double *)(PyArray_DATA(capi_x_tmp));

  /* Processing variable npts */
  npts = len(x);
  /* Processing variable nptso */
  nptso = len(olats);
  /* Processing variable olons */
  olons_Dims[0]=nptso;
  capi_olons_intent |= F2PY_INTENT_IN;
  capi_olons_tmp = array_from_pyobj(NPY_DOUBLE,olons_Dims,olons_Rank,capi_olons_intent,olons_capi);
  if (capi_olons_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 3rd argument `olons' of _stripack.interp_n to C/Fortran array" );
  } else {
    olons = (double *)(PyArray_DATA(capi_olons_tmp));

  /* Processing variable y */
  y_Dims[0]=npts;
  capi_y_intent |= F2PY_INTENT_IN;
  capi_y_tmp = array_from_pyobj(NPY_DOUBLE,y_Dims,y_Rank,capi_y_intent,y_capi);
  if (capi_y_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 5th argument `y' of _stripack.interp_n to C/Fortran array" );
  } else {
    y = (double *)(PyArray_DATA(capi_y_tmp));

  /* Processing variable z */
  z_Dims[0]=npts;
  capi_z_intent |= F2PY_INTENT_IN;
  capi_z_tmp = array_from_pyobj(NPY_DOUBLE,z_Dims,z_Rank,capi_z_intent,z_capi);
  if (capi_z_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 6th argument `z' of _stripack.interp_n to C/Fortran array" );
  } else {
    z = (double *)(PyArray_DATA(capi_z_tmp));

  /* Processing variable data */
  data_Dims[0]=npts;
  capi_data_intent |= F2PY_INTENT_IN;
  capi_data_tmp = array_from_pyobj(NPY_DOUBLE,data_Dims,data_Rank,capi_data_intent,data_capi);
  if (capi_data_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 7th argument `data' of _stripack.interp_n to C/Fortran array" );
  } else {
    data = (double *)(PyArray_DATA(capi_data_tmp));

  /* Processing variable odata */
  odata_Dims[0]=nptso;
  capi_odata_intent |= F2PY_INTENT_OUT|F2PY_INTENT_HIDE;
  capi_odata_tmp = array_from_pyobj(NPY_DOUBLE,odata_Dims,odata_Rank,capi_odata_intent,Py_None);
  if (capi_odata_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting hidden `odata' of _stripack.interp_n to C/Fortran array" );
  } else {
    odata = (double *)(PyArray_DATA(capi_odata_tmp));

  /* Processing variable lend */
  lend_Dims[0]=npts;
  capi_lend_intent |= F2PY_INTENT_IN;
  capi_lend_tmp = array_from_pyobj(NPY_INT,lend_Dims,lend_Rank,capi_lend_intent,lend_capi);
  if (capi_lend_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 10th argument `lend' of _stripack.interp_n to C/Fortran array" );
  } else {
    lend = (int *)(PyArray_DATA(capi_lend_tmp));

  /* Processing variable lst */
  lst_Dims[0]=6 * npts - 12;
  capi_lst_intent |= F2PY_INTENT_IN;
  capi_lst_tmp = array_from_pyobj(NPY_INT,lst_Dims,lst_Rank,capi_lst_intent,lst_capi);
  if (capi_lst_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 8th argument `lst' of _stripack.interp_n to C/Fortran array" );
  } else {
    lst = (int *)(PyArray_DATA(capi_lst_tmp));

  /* Processing variable lptr */
  lptr_Dims[0]=6 * npts - 12;
  capi_lptr_intent |= F2PY_INTENT_IN;
  capi_lptr_tmp = array_from_pyobj(NPY_INT,lptr_Dims,lptr_Rank,capi_lptr_intent,lptr_capi);
  if (capi_lptr_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 9th argument `lptr' of _stripack.interp_n to C/Fortran array" );
  } else {
    lptr = (int *)(PyArray_DATA(capi_lptr_tmp));

  /* Processing variable edata */
  edata_Dims[0]=nptso;
  capi_edata_intent |= F2PY_INTENT_OUT|F2PY_INTENT_HIDE;
  capi_edata_tmp = array_from_pyobj(NPY_INT,edata_Dims,edata_Rank,capi_edata_intent,Py_None);
  if (capi_edata_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting hidden `edata' of _stripack.interp_n to C/Fortran array" );
  } else {
    edata = (int *)(PyArray_DATA(capi_edata_tmp));

/*end of frompyobj*/
#ifdef F2PY_REPORT_ATEXIT
f2py_start_call_clock();
#endif
/*callfortranroutine*/
        (*f2py_func)(&npts,&nptso,&order,olats,olons,x,y,z,data,lst,lptr,lend,odata,edata,&ierr);
if (PyErr_Occurred())
  f2py_success = 0;
#ifdef F2PY_REPORT_ATEXIT
f2py_stop_call_clock();
#endif
/*end of callfortranroutine*/
    if (f2py_success) {
/*pyobjfrom*/
/*end of pyobjfrom*/
    CFUNCSMESS("Building return value.\n");
    capi_buildvalue = Py_BuildValue("NNi",capi_odata_tmp,capi_edata_tmp,ierr);
/*closepyobjfrom*/
/*end of closepyobjfrom*/
    } /*if (f2py_success) after callfortranroutine*/
/*cleanupfrompyobj*/
  }  /*if (capi_edata_tmp == NULL) ... else of edata*/
  /* End of cleaning variable edata */
  if((PyObject *)capi_lptr_tmp!=lptr_capi) {
    Py_XDECREF(capi_lptr_tmp); }
  }  /*if (capi_lptr_tmp == NULL) ... else of lptr*/
  /* End of cleaning variable lptr */
  if((PyObject *)capi_lst_tmp!=lst_capi) {
    Py_XDECREF(capi_lst_tmp); }
  }  /*if (capi_lst_tmp == NULL) ... else of lst*/
  /* End of cleaning variable lst */
  if((PyObject *)capi_lend_tmp!=lend_capi) {
    Py_XDECREF(capi_lend_tmp); }
  }  /*if (capi_lend_tmp == NULL) ... else of lend*/
  /* End of cleaning variable lend */
  }  /*if (capi_odata_tmp == NULL) ... else of odata*/
  /* End of cleaning variable odata */
  if((PyObject *)capi_data_tmp!=data_capi) {
    Py_XDECREF(capi_data_tmp); }
  }  /*if (capi_data_tmp == NULL) ... else of data*/
  /* End of cleaning variable data */
  if((PyObject *)capi_z_tmp!=z_capi) {
    Py_XDECREF(capi_z_tmp); }
  }  /*if (capi_z_tmp == NULL) ... else of z*/
  /* End of cleaning variable z */
  if((PyObject *)capi_y_tmp!=y_capi) {
    Py_XDECREF(capi_y_tmp); }
  }  /*if (capi_y_tmp == NULL) ... else of y*/
  /* End of cleaning variable y */
  if((PyObject *)capi_olons_tmp!=olons_capi) {
    Py_XDECREF(capi_olons_tmp); }
  }  /*if (capi_olons_tmp == NULL) ... else of olons*/
  /* End of cleaning variable olons */
  /* End of cleaning variable nptso */
  /* End of cleaning variable npts */
  if((PyObject *)capi_x_tmp!=x_capi) {
    Py_XDECREF(capi_x_tmp); }
  }  /*if (capi_x_tmp == NULL) ... else of x*/
  /* End of cleaning variable x */
  if((PyObject *)capi_olats_tmp!=olats_capi) {
    Py_XDECREF(capi_olats_tmp); }
  }  /*if (capi_olats_tmp == NULL) ... else of olats*/
  /* End of cleaning variable olats */
  /* End of cleaning variable ierr */
  } /*if (f2py_success) of order*/
  /* End of cleaning variable order */
/*end of cleanupfrompyobj*/
  if (capi_buildvalue == NULL) {
/*routdebugfailure*/
  } else {
/*routdebugleave*/
  }
  CFUNCSMESS("Freeing memory.\n");
/*freemem*/
#ifdef F2PY_REPORT_ATEXIT
f2py_stop_clock();
#endif
  return capi_buildvalue;
}
/****************************** end of interp_n ******************************/

/*********************************** trlist ***********************************/
static char doc_f2py_rout__stripack_trlist[] = "\
nt,ltri,ier = trlist(list,lptr,lend,[n,nrow])\n\nWrapper for ``trlist``.\
\n\nParameters\n----------\n"
"list : input rank-1 array('i') with bounds (6 * n - 12)\n"
"lptr : input rank-1 array('i') with bounds (6 * n - 12)\n"
"lend : input rank-1 array('i') with bounds (n)\n"
"\nOther Parameters\n----------------\n"
"n : input int, optional\n    Default: len(lend)\n"
"nrow : input int, optional\n    Default: 6\n"
"\nReturns\n-------\n"
"nt : int\n"
"ltri : rank-2 array('i') with bounds (nrow,2 * n - 4)\n"
"ier : int";
/* extern void F_FUNC(trlist,TRLIST)(int*,int*,int*,int*,int*,int*,int*,int*); */
static PyObject *f2py_rout__stripack_trlist(const PyObject *capi_self,
                           PyObject *capi_args,
                           PyObject *capi_keywds,
                           void (*f2py_func)(int*,int*,int*,int*,int*,int*,int*,int*)) {
  PyObject * volatile capi_buildvalue = NULL;
  volatile int f2py_success = 1;
/*decl*/

  int n = 0;
  PyObject *n_capi = Py_None;
  int *list = NULL;
  npy_intp list_Dims[1] = {-1};
  const int list_Rank = 1;
  PyArrayObject *capi_list_tmp = NULL;
  int capi_list_intent = 0;
  PyObject *list_capi = Py_None;
  int *lptr = NULL;
  npy_intp lptr_Dims[1] = {-1};
  const int lptr_Rank = 1;
  PyArrayObject *capi_lptr_tmp = NULL;
  int capi_lptr_intent = 0;
  PyObject *lptr_capi = Py_None;
  int *lend = NULL;
  npy_intp lend_Dims[1] = {-1};
  const int lend_Rank = 1;
  PyArrayObject *capi_lend_tmp = NULL;
  int capi_lend_intent = 0;
  PyObject *lend_capi = Py_None;
  int nrow = 0;
  PyObject *nrow_capi = Py_None;
  int nt = 0;
  int *ltri = NULL;
  npy_intp ltri_Dims[2] = {-1, -1};
  const int ltri_Rank = 2;
  PyArrayObject *capi_ltri_tmp = NULL;
  int capi_ltri_intent = 0;
  int ier = 0;
  static char *capi_kwlist[] = {"list","lptr","lend","n","nrow",NULL};

/*routdebugenter*/
#ifdef F2PY_REPORT_ATEXIT
f2py_start_clock();
#endif
  if (!PyArg_ParseTupleAndKeywords(capi_args,capi_keywds,\
    "OOO|OO:_stripack.trlist",\
    capi_kwlist,&list_capi,&lptr_capi,&lend_capi,&n_capi,&nrow_capi))
    return NULL;
/*frompyobj*/
  /* Processing variable lend */
  ;
  capi_lend_intent |= F2PY_INTENT_IN;
  capi_lend_tmp = array_from_pyobj(NPY_INT,lend_Dims,lend_Rank,capi_lend_intent,lend_capi);
  if (capi_lend_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 3rd argument `lend' of _stripack.trlist to C/Fortran array" );
  } else {
    lend = (int *)(PyArray_DATA(capi_lend_tmp));

  /* Processing variable nrow */
  if (nrow_capi == Py_None) nrow = 6; else
    f2py_success = int_from_pyobj(&nrow,nrow_capi,"_stripack.trlist() 2nd keyword (nrow) can't be converted to int");
  if (f2py_success) {
  /* Processing variable nt */
  /* Processing variable ier */
  /* Processing variable n */
  if (n_capi == Py_None) n = len(lend); else
    f2py_success = int_from_pyobj(&n,n_capi,"_stripack.trlist() 1st keyword (n) can't be converted to int");
  if (f2py_success) {
  /* Processing variable list */
  list_Dims[0]=6 * n - 12;
  capi_list_intent |= F2PY_INTENT_IN;
  capi_list_tmp = array_from_pyobj(NPY_INT,list_Dims,list_Rank,capi_list_intent,list_capi);
  if (capi_list_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 1st argument `list' of _stripack.trlist to C/Fortran array" );
  } else {
    list = (int *)(PyArray_DATA(capi_list_tmp));

  /* Processing variable lptr */
  lptr_Dims[0]=6 * n - 12;
  capi_lptr_intent |= F2PY_INTENT_IN;
  capi_lptr_tmp = array_from_pyobj(NPY_INT,lptr_Dims,lptr_Rank,capi_lptr_intent,lptr_capi);
  if (capi_lptr_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 2nd argument `lptr' of _stripack.trlist to C/Fortran array" );
  } else {
    lptr = (int *)(PyArray_DATA(capi_lptr_tmp));

  /* Processing variable ltri */
  ltri_Dims[0]=nrow,ltri_Dims[1]=2 * n - 4;
  capi_ltri_intent |= F2PY_INTENT_OUT|F2PY_INTENT_HIDE;
  capi_ltri_tmp = array_from_pyobj(NPY_INT,ltri_Dims,ltri_Rank,capi_ltri_intent,Py_None);
  if (capi_ltri_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting hidden `ltri' of _stripack.trlist to C/Fortran array" );
  } else {
    ltri = (int *)(PyArray_DATA(capi_ltri_tmp));

/*end of frompyobj*/
#ifdef F2PY_REPORT_ATEXIT
f2py_start_call_clock();
#endif
/*callfortranroutine*/
        (*f2py_func)(&n,list,lptr,lend,&nrow,&nt,ltri,&ier);
if (PyErr_Occurred())
  f2py_success = 0;
#ifdef F2PY_REPORT_ATEXIT
f2py_stop_call_clock();
#endif
/*end of callfortranroutine*/
    if (f2py_success) {
/*pyobjfrom*/
/*end of pyobjfrom*/
    CFUNCSMESS("Building return value.\n");
    capi_buildvalue = Py_BuildValue("iNi",nt,capi_ltri_tmp,ier);
/*closepyobjfrom*/
/*end of closepyobjfrom*/
    } /*if (f2py_success) after callfortranroutine*/
/*cleanupfrompyobj*/
  }  /*if (capi_ltri_tmp == NULL) ... else of ltri*/
  /* End of cleaning variable ltri */
  if((PyObject *)capi_lptr_tmp!=lptr_capi) {
    Py_XDECREF(capi_lptr_tmp); }
  }  /*if (capi_lptr_tmp == NULL) ... else of lptr*/
  /* End of cleaning variable lptr */
  if((PyObject *)capi_list_tmp!=list_capi) {
    Py_XDECREF(capi_list_tmp); }
  }  /*if (capi_list_tmp == NULL) ... else of list*/
  /* End of cleaning variable list */
  } /*if (f2py_success) of n*/
  /* End of cleaning variable n */
  /* End of cleaning variable ier */
  /* End of cleaning variable nt */
  } /*if (f2py_success) of nrow*/
  /* End of cleaning variable nrow */
  if((PyObject *)capi_lend_tmp!=lend_capi) {
    Py_XDECREF(capi_lend_tmp); }
  }  /*if (capi_lend_tmp == NULL) ... else of lend*/
  /* End of cleaning variable lend */
/*end of cleanupfrompyobj*/
  if (capi_buildvalue == NULL) {
/*routdebugfailure*/
  } else {
/*routdebugleave*/
  }
  CFUNCSMESS("Freeing memory.\n");
/*freemem*/
#ifdef F2PY_REPORT_ATEXIT
f2py_stop_clock();
#endif
  return capi_buildvalue;
}
/******************************* end of trlist *******************************/

/********************************** trlist2 **********************************/
static char doc_f2py_rout__stripack_trlist2[] = "\
nt,ltri,ier = trlist2(list,lptr,lend)\n\nWrapper for ``trlist2``.\
\n\nParameters\n----------\n"
"list : input rank-1 array('i') with bounds (6 * n - 12)\n"
"lptr : input rank-1 array('i') with bounds (6 * n - 12)\n"
"lend : input rank-1 array('i') with bounds (n)\n"
"\nReturns\n-------\n"
"nt : int\n"
"ltri : rank-2 array('i') with bounds (3,2 * n - 4)\n"
"ier : int";
/* extern void F_FUNC(trlist2,TRLIST2)(int*,int*,int*,int*,int*,int*,int*); */
static PyObject *f2py_rout__stripack_trlist2(const PyObject *capi_self,
                           PyObject *capi_args,
                           PyObject *capi_keywds,
                           void (*f2py_func)(int*,int*,int*,int*,int*,int*,int*)) {
  PyObject * volatile capi_buildvalue = NULL;
  volatile int f2py_success = 1;
/*decl*/

  int n = 0;
  int *list = NULL;
  npy_intp list_Dims[1] = {-1};
  const int list_Rank = 1;
  PyArrayObject *capi_list_tmp = NULL;
  int capi_list_intent = 0;
  PyObject *list_capi = Py_None;
  int *lptr = NULL;
  npy_intp lptr_Dims[1] = {-1};
  const int lptr_Rank = 1;
  PyArrayObject *capi_lptr_tmp = NULL;
  int capi_lptr_intent = 0;
  PyObject *lptr_capi = Py_None;
  int *lend = NULL;
  npy_intp lend_Dims[1] = {-1};
  const int lend_Rank = 1;
  PyArrayObject *capi_lend_tmp = NULL;
  int capi_lend_intent = 0;
  PyObject *lend_capi = Py_None;
  int nt = 0;
  int *ltri = NULL;
  npy_intp ltri_Dims[2] = {-1, -1};
  const int ltri_Rank = 2;
  PyArrayObject *capi_ltri_tmp = NULL;
  int capi_ltri_intent = 0;
  int ier = 0;
  static char *capi_kwlist[] = {"list","lptr","lend",NULL};

/*routdebugenter*/
#ifdef F2PY_REPORT_ATEXIT
f2py_start_clock();
#endif
  if (!PyArg_ParseTupleAndKeywords(capi_args,capi_keywds,\
    "OOO:_stripack.trlist2",\
    capi_kwlist,&list_capi,&lptr_capi,&lend_capi))
    return NULL;
/*frompyobj*/
  /* Processing variable lend */
  ;
  capi_lend_intent |= F2PY_INTENT_IN;
  capi_lend_tmp = array_from_pyobj(NPY_INT,lend_Dims,lend_Rank,capi_lend_intent,lend_capi);
  if (capi_lend_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 3rd argument `lend' of _stripack.trlist2 to C/Fortran array" );
  } else {
    lend = (int *)(PyArray_DATA(capi_lend_tmp));

  /* Processing variable nt */
  /* Processing variable ier */
  /* Processing variable n */
  n = len(lend);
  /* Processing variable list */
  list_Dims[0]=6 * n - 12;
  capi_list_intent |= F2PY_INTENT_IN;
  capi_list_tmp = array_from_pyobj(NPY_INT,list_Dims,list_Rank,capi_list_intent,list_capi);
  if (capi_list_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 1st argument `list' of _stripack.trlist2 to C/Fortran array" );
  } else {
    list = (int *)(PyArray_DATA(capi_list_tmp));

  /* Processing variable lptr */
  lptr_Dims[0]=6 * n - 12;
  capi_lptr_intent |= F2PY_INTENT_IN;
  capi_lptr_tmp = array_from_pyobj(NPY_INT,lptr_Dims,lptr_Rank,capi_lptr_intent,lptr_capi);
  if (capi_lptr_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting 2nd argument `lptr' of _stripack.trlist2 to C/Fortran array" );
  } else {
    lptr = (int *)(PyArray_DATA(capi_lptr_tmp));

  /* Processing variable ltri */
  ltri_Dims[0]=3,ltri_Dims[1]=2 * n - 4;
  capi_ltri_intent |= F2PY_INTENT_OUT|F2PY_INTENT_HIDE;
  capi_ltri_tmp = array_from_pyobj(NPY_INT,ltri_Dims,ltri_Rank,capi_ltri_intent,Py_None);
  if (capi_ltri_tmp == NULL) {
    if (!PyErr_Occurred())
      PyErr_SetString(_stripack_error,"failed in converting hidden `ltri' of _stripack.trlist2 to C/Fortran array" );
  } else {
    ltri = (int *)(PyArray_DATA(capi_ltri_tmp));

/*end of frompyobj*/
#ifdef F2PY_REPORT_ATEXIT
f2py_start_call_clock();
#endif
/*callfortranroutine*/
        (*f2py_func)(&n,list,lptr,lend,&nt,ltri,&ier);
if (PyErr_Occurred())
  f2py_success = 0;
#ifdef F2PY_REPORT_ATEXIT
f2py_stop_call_clock();
#endif
/*end of callfortranroutine*/
    if (f2py_success) {
/*pyobjfrom*/
/*end of pyobjfrom*/
    CFUNCSMESS("Building return value.\n");
    capi_buildvalue = Py_BuildValue("iNi",nt,capi_ltri_tmp,ier);
/*closepyobjfrom*/
/*end of closepyobjfrom*/
    } /*if (f2py_success) after callfortranroutine*/
/*cleanupfrompyobj*/
  }  /*if (capi_ltri_tmp == NULL) ... else of ltri*/
  /* End of cleaning variable ltri */
  if((PyObject *)capi_lptr_tmp!=lptr_capi) {
    Py_XDECREF(capi_lptr_tmp); }
  }  /*if (capi_lptr_tmp == NULL) ... else of lptr*/
  /* End of cleaning variable lptr */
  if((PyObject *)capi_list_tmp!=list_capi) {
    Py_XDECREF(capi_list_tmp); }
  }  /*if (capi_list_tmp == NULL) ... else of list*/
  /* End of cleaning variable list */
  /* End of cleaning variable n */
  /* End of cleaning variable ier */
  /* End of cleaning variable nt */
  if((PyObject *)capi_lend_tmp!=lend_capi) {
    Py_XDECREF(capi_lend_tmp); }
  }  /*if (capi_lend_tmp == NULL) ... else of lend*/
  /* End of cleaning variable lend */
/*end of cleanupfrompyobj*/
  if (capi_buildvalue == NULL) {
/*routdebugfailure*/
  } else {
/*routdebugleave*/
  }
  CFUNCSMESS("Freeing memory.\n");
/*freemem*/
#ifdef F2PY_REPORT_ATEXIT
f2py_stop_clock();
#endif
  return capi_buildvalue;
}
/******************************* end of trlist2 *******************************/
/*eof body*/

/******************* See f2py2e/f90mod_rules.py: buildhooks *******************/
/*need_f90modhooks*/

/************** See f2py2e/rules.py: module_rules['modulebody'] **************/

/******************* See f2py2e/common_rules.py: buildhooks *******************/

/*need_commonhooks*/

/**************************** See f2py2e/rules.py ****************************/

static FortranDataDef f2py_routine_defs[] = {
  {"addnod",-1,{{-1}},0,(char *)F_FUNC(addnod,ADDNOD),(f2py_init_func)f2py_rout__stripack_addnod,doc_f2py_rout__stripack_addnod},
  {"arc_cosine",-1,{{-1}},0,(char *)F_WRAPPEDFUNC_US(arc_cosine,ARC_COSINE),(f2py_init_func)f2py_rout__stripack_arc_cosine,doc_f2py_rout__stripack_arc_cosine},
  {"areas",-1,{{-1}},0,(char *)F_WRAPPEDFUNC(areas,AREAS),(f2py_init_func)f2py_rout__stripack_areas,doc_f2py_rout__stripack_areas},
  {"triareas",-1,{{-1}},0,(char *)F_FUNC(triareas,TRIAREAS),(f2py_init_func)f2py_rout__stripack_triareas,doc_f2py_rout__stripack_triareas},
  {"bnodes",-1,{{-1}},0,(char *)F_FUNC(bnodes,BNODES),(f2py_init_func)f2py_rout__stripack_bnodes,doc_f2py_rout__stripack_bnodes},
  {"circum",-1,{{-1}},0,(char *)F_FUNC(circum,CIRCUM),(f2py_init_func)f2py_rout__stripack_circum,doc_f2py_rout__stripack_circum},
  {"crlist",-1,{{-1}},0,(char *)F_FUNC(crlist,CRLIST),(f2py_init_func)f2py_rout__stripack_crlist,doc_f2py_rout__stripack_crlist},
  {"delarc",-1,{{-1}},0,(char *)F_FUNC(delarc,DELARC),(f2py_init_func)f2py_rout__stripack_delarc,doc_f2py_rout__stripack_delarc},
  {"delnod",-1,{{-1}},0,(char *)F_FUNC(delnod,DELNOD),(f2py_init_func)f2py_rout__stripack_delnod,doc_f2py_rout__stripack_delnod},
  {"edge",-1,{{-1}},0,(char *)F_FUNC(edge,EDGE),(f2py_init_func)f2py_rout__stripack_edge,doc_f2py_rout__stripack_edge},
  {"nearnd",-1,{{-1}},0,(char *)F_WRAPPEDFUNC(nearnd,NEARND),(f2py_init_func)f2py_rout__stripack_nearnd,doc_f2py_rout__stripack_nearnd},
  {"trans",-1,{{-1}},0,(char *)F_FUNC(trans,TRANS),(f2py_init_func)f2py_rout__stripack_trans,doc_f2py_rout__stripack_trans},
  {"trfind",-1,{{-1}},0,(char *)F_FUNC(trfind,TRFIND),(f2py_init_func)f2py_rout__stripack_trfind,doc_f2py_rout__stripack_trfind},
  {"trmesh",-1,{{-1}},0,(char *)F_FUNC(trmesh,TRMESH),(f2py_init_func)f2py_rout__stripack_trmesh,doc_f2py_rout__stripack_trmesh},
  {"interp",-1,{{-1}},0,(char *)F_FUNC(interp,INTERP),(f2py_init_func)f2py_rout__stripack_interp,doc_f2py_rout__stripack_interp},
  {"getnp",-1,{{-1}},0,(char *)F_FUNC(getnp,GETNP),(f2py_init_func)f2py_rout__stripack_getnp,doc_f2py_rout__stripack_getnp},
  {"interp_n",-1,{{-1}},0,(char *)F_FUNC_US(interp_n,INTERP_N),(f2py_init_func)f2py_rout__stripack_interp_n,doc_f2py_rout__stripack_interp_n},
  {"trlist",-1,{{-1}},0,(char *)F_FUNC(trlist,TRLIST),(f2py_init_func)f2py_rout__stripack_trlist,doc_f2py_rout__stripack_trlist},
  {"trlist2",-1,{{-1}},0,(char *)F_FUNC(trlist2,TRLIST2),(f2py_init_func)f2py_rout__stripack_trlist2,doc_f2py_rout__stripack_trlist2},

/*eof routine_defs*/
  {NULL}
};

static PyMethodDef f2py_module_methods[] = {

  {NULL,NULL}
};

#if PY_VERSION_HEX >= 0x03000000
static struct PyModuleDef moduledef = {
  PyModuleDef_HEAD_INIT,
  "_stripack",
  NULL,
  -1,
  f2py_module_methods,
  NULL,
  NULL,
  NULL,
  NULL
};
#endif

#if PY_VERSION_HEX >= 0x03000000
#define RETVAL m
PyMODINIT_FUNC PyInit__stripack(void) {
#else
#define RETVAL
PyMODINIT_FUNC init_stripack(void) {
#endif
  int i;
  PyObject *m,*d, *s;
#if PY_VERSION_HEX >= 0x03000000
  m = _stripack_module = PyModule_Create(&moduledef);
#else
  m = _stripack_module = Py_InitModule("_stripack", f2py_module_methods);
#endif
  Py_TYPE(&PyFortran_Type) = &PyType_Type;
  import_array();
  if (PyErr_Occurred())
    {PyErr_SetString(PyExc_ImportError, "can't initialize module _stripack (failed to import numpy)"); return RETVAL;}
  d = PyModule_GetDict(m);
  s = PyString_FromString("$Revision: $");
  PyDict_SetItemString(d, "__version__", s);
#if PY_VERSION_HEX >= 0x03000000
  s = PyUnicode_FromString(
#else
  s = PyString_FromString(
#endif
    "This module '_stripack' is auto-generated with f2py (version:2).\nFunctions:\n"
"  list,lptr,lend,lnew,ier = addnod(x,y,z,list,lptr,lend,lnew,nst=1)\n"
"  arc_cosine = arc_cosine(c)\n"
"  areas = areas(v1,v2,v3)\n"
"  triarea = triareas(x,y,z,triangles)\n"
"  nb,na,nt = bnodes(list,lptr,lend,nodes)\n"
"  c,ier = circum(v1,v2,v3)\n"
"  lptr,lnew,ltri,listc,nb,xc,yc,zc,rc,ier = crlist(ncol,x,y,z,list,lend,lptr,lnew)\n"
"  list,lptr,lend,lnew,ier = delarc(io1,io2,list,lptr,lend,lnew)\n"
"  x,y,z,list,lptr,lend,lnew,lwk,iwk,ier = delnod(k,x,y,z,list,lptr,lend,lnew,iwk,lwk=shape(iwk,1))\n"
"  lwk,iwk,list,lptr,lend,ier = edge(in1,in2,x,y,z,lwk,list,lptr,lend)\n"
"  nearnd,al = nearnd(p,x,y,z,list,lptr,lend,ist=1)\n"
"  x,y,z = trans(rlat,rlon)\n"
"  b1,b2,b3,i1,i2,i3 = trfind(nst,p,x,y,z,list,lptr,lend)\n"
"  list,lptr,lend,ier = trmesh(x,y,z)\n"
"  interp(order,plat,plon,x,y,z,w,list,lptr,lend,ist,pw,ier,n=len(x))\n"
"  list,lend,npts,df,ier = getnp(x,y,z,list,lptr,npts,l=len(npts))\n"
"  odata,edata,ierr = interp_n(order,olats,olons,x,y,z,data,lst,lptr,lend)\n"
"  nt,ltri,ier = trlist(list,lptr,lend,n=len(lend),nrow=6)\n"
"  nt,ltri,ier = trlist2(list,lptr,lend)\n"
".");
  PyDict_SetItemString(d, "__doc__", s);
  _stripack_error = PyErr_NewException ("_stripack.error", NULL, NULL);
  Py_DECREF(s);
  for(i=0;f2py_routine_defs[i].name!=NULL;i++)
    PyDict_SetItemString(d, f2py_routine_defs[i].name,PyFortranObject_NewAsAttr(&f2py_routine_defs[i]));


    {
      extern double F_FUNC_US(arc_cosine,ARC_COSINE)(void);
      PyObject* o = PyDict_GetItemString(d,"arc_cosine");
      PyObject_SetAttrString(o,"_cpointer", F2PyCapsule_FromVoidPtr((void*)F_FUNC_US(arc_cosine,ARC_COSINE),NULL));
#if PY_VERSION_HEX >= 0x03000000
      PyObject_SetAttrString(o,"__name__", PyUnicode_FromString("arc_cosine"));
#else
      PyObject_SetAttrString(o,"__name__", PyString_FromString("arc_cosine"));
#endif
    }
    

    {
      extern double F_FUNC(areas,AREAS)(void);
      PyObject* o = PyDict_GetItemString(d,"areas");
      PyObject_SetAttrString(o,"_cpointer", F2PyCapsule_FromVoidPtr((void*)F_FUNC(areas,AREAS),NULL));
#if PY_VERSION_HEX >= 0x03000000
      PyObject_SetAttrString(o,"__name__", PyUnicode_FromString("areas"));
#else
      PyObject_SetAttrString(o,"__name__", PyString_FromString("areas"));
#endif
    }
    








    {
      extern int F_FUNC(nearnd,NEARND)(void);
      PyObject* o = PyDict_GetItemString(d,"nearnd");
      PyObject_SetAttrString(o,"_cpointer", F2PyCapsule_FromVoidPtr((void*)F_FUNC(nearnd,NEARND),NULL));
#if PY_VERSION_HEX >= 0x03000000
      PyObject_SetAttrString(o,"__name__", PyUnicode_FromString("nearnd"));
#else
      PyObject_SetAttrString(o,"__name__", PyString_FromString("nearnd"));
#endif
    }
    








/*eof initf2pywraphooks*/
/*eof initf90modhooks*/

/*eof initcommonhooks*/


#ifdef F2PY_REPORT_ATEXIT
  if (! PyErr_Occurred())
    on_exit(f2py_report_on_exit,(void*)"_stripack");
#endif

  return RETVAL;
}
#ifdef __cplusplus
}
#endif
